# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

_SNAKE_TO_CAMEL_CASE_TABLE = {
    "accelerator_type": "acceleratorType",
    "access_context_manager_custom_endpoint": "accessContextManagerCustomEndpoint",
    "access_token": "accessToken",
    "account_id": "accountId",
    "ack_deadline_seconds": "ackDeadlineSeconds",
    "additional_zones": "additionalZones",
    "addons_config": "addonsConfig",
    "address_type": "addressType",
    "admin_enabled": "adminEnabled",
    "admission_whitelist_patterns": "admissionWhitelistPatterns",
    "advertise_mode": "advertiseMode",
    "advertised_groups": "advertisedGroups",
    "advertised_ip_ranges": "advertisedIpRanges",
    "advertised_route_priority": "advertisedRoutePriority",
    "affinity_cookie_ttl_sec": "affinityCookieTtlSec",
    "all_ports": "allPorts",
    "allow_stopping_for_update": "allowStoppingForUpdate",
    "alternative_location_id": "alternativeLocationId",
    "alternative_name_server_config": "alternativeNameServerConfig",
    "app_engine_custom_endpoint": "appEngineCustomEndpoint",
    "app_engine_http_target": "appEngineHttpTarget",
    "app_id": "appId",
    "app_profile_id": "appProfileId",
    "archive_size_bytes": "archiveSizeBytes",
    "attached_disks": "attachedDisks",
    "attestation_authority": "attestationAuthority",
    "attestation_authority_note": "attestationAuthorityNote",
    "audit_log_configs": "auditLogConfigs",
    "auth_domain": "authDomain",
    "authenticator_groups_config": "authenticatorGroupsConfig",
    "authorized_network": "authorizedNetwork",
    "auto_create_network": "autoCreateNetwork",
    "auto_create_routes": "autoCreateRoutes",
    "auto_create_subnetworks": "autoCreateSubnetworks",
    "auto_healing_policies": "autoHealingPolicies",
    "autoscaling_policy": "autoscalingPolicy",
    "available_memory_mb": "availableMemoryMb",
    "backend_bucket": "backendBucket",
    "backend_service": "backendService",
    "backup_pool": "backupPool",
    "base_instance_name": "baseInstanceName",
    "basic_algorithm": "basicAlgorithm",
    "big_query_custom_endpoint": "bigQueryCustomEndpoint",
    "bigquery_data_transfer_custom_endpoint": "bigqueryDataTransferCustomEndpoint",
    "bigtable_custom_endpoint": "bigtableCustomEndpoint",
    "billing_account": "billingAccount",
    "billing_account_id": "billingAccountId",
    "binary_authorization_custom_endpoint": "binaryAuthorizationCustomEndpoint",
    "blacklist_patterns": "blacklistPatterns",
    "boolean_policy": "booleanPolicy",
    "boot_disk": "bootDisk",
    "bucket_name": "bucketName",
    "bucket_options": "bucketOptions",
    "bucket_policy_only": "bucketPolicyOnly",
    "cache_control": "cacheControl",
    "can_ip_forward": "canIpForward",
    "candidate_subnets": "candidateSubnets",
    "cdn_policy": "cdnPolicy",
    "cert_serial_number": "certSerialNumber",
    "certificate_id": "certificateId",
    "check_interval_sec": "checkIntervalSec",
    "cidr_block": "cidrBlock",
    "circuit_breakers": "circuitBreakers",
    "cloud_billing_custom_endpoint": "cloudBillingCustomEndpoint",
    "cloud_build_custom_endpoint": "cloudBuildCustomEndpoint",
    "cloud_function": "cloudFunction",
    "cloud_functions_custom_endpoint": "cloudFunctionsCustomEndpoint",
    "cloud_iot_custom_endpoint": "cloudIotCustomEndpoint",
    "cloud_router_ip_address": "cloudRouterIpAddress",
    "cloud_run_custom_endpoint": "cloudRunCustomEndpoint",
    "cloud_scheduler_custom_endpoint": "cloudSchedulerCustomEndpoint",
    "cluster_admission_rules": "clusterAdmissionRules",
    "cluster_autoscaling": "clusterAutoscaling",
    "cluster_config": "clusterConfig",
    "cluster_ipv4_cidr": "clusterIpv4Cidr",
    "code_bucket": "codeBucket",
    "column_families": "columnFamilies",
    "column_family": "columnFamily",
    "common_name": "commonName",
    "composer_custom_endpoint": "composerCustomEndpoint",
    "compute_beta_custom_endpoint": "computeBetaCustomEndpoint",
    "compute_custom_endpoint": "computeCustomEndpoint",
    "config_id": "configId",
    "connection_draining_timeout_sec": "connectionDrainingTimeoutSec",
    "connection_name": "connectionName",
    "consistent_hash": "consistentHash",
    "container_analysis_custom_endpoint": "containerAnalysisCustomEndpoint",
    "container_beta_custom_endpoint": "containerBetaCustomEndpoint",
    "container_custom_endpoint": "containerCustomEndpoint",
    "content_disposition": "contentDisposition",
    "content_encoding": "contentEncoding",
    "content_language": "contentLanguage",
    "content_matchers": "contentMatchers",
    "content_type": "contentType",
    "cpu_platform": "cpuPlatform",
    "create_time": "createTime",
    "creation_record": "creationRecord",
    "creation_time": "creationTime",
    "creation_timestamp": "creationTimestamp",
    "crypto_key_id": "cryptoKeyId",
    "current_location_id": "currentLocationId",
    "custom_attributes": "customAttributes",
    "custom_features": "customFeatures",
    "custom_request_headers": "customRequestHeaders",
    "customer_router_ip_address": "customerRouterIpAddress",
    "data_refresh_window_days": "dataRefreshWindowDays",
    "data_source_id": "dataSourceId",
    "database_encryption": "databaseEncryption",
    "database_version": "databaseVersion",
    "dataflow_custom_endpoint": "dataflowCustomEndpoint",
    "dataproc_beta_custom_endpoint": "dataprocBetaCustomEndpoint",
    "dataproc_custom_endpoint": "dataprocCustomEndpoint",
    "dataset_id": "datasetId",
    "default_acl": "defaultAcl",
    "default_admission_rule": "defaultAdmissionRule",
    "default_bucket": "defaultBucket",
    "default_encryption_configuration": "defaultEncryptionConfiguration",
    "default_hostname": "defaultHostname",
    "default_max_pods_per_node": "defaultMaxPodsPerNode",
    "default_partition_expiration_ms": "defaultPartitionExpirationMs",
    "default_port": "defaultPort",
    "default_service": "defaultService",
    "default_table_expiration_ms": "defaultTableExpirationMs",
    "default_version": "defaultVersion",
    "delete_contents_on_destroy": "deleteContentsOnDestroy",
    "delete_default_routes_on_create": "deleteDefaultRoutesOnCreate",
    "delete_service_on_destroy": "deleteServiceOnDestroy",
    "deletion_protection": "deletionProtection",
    "deletion_time": "deletionTime",
    "dest_range": "destRange",
    "destination_dataset_id": "destinationDatasetId",
    "destination_ranges": "destinationRanges",
    "detailed_status": "detailedStatus",
    "detect_md5hash": "detectMd5hash",
    "device_name": "deviceName",
    "dicom_store_id": "dicomStoreId",
    "disable_dependent_services": "disableDependentServices",
    "disable_on_destroy": "disableOnDestroy",
    "disable_referential_integrity": "disableReferentialIntegrity",
    "disable_resource_versioning": "disableResourceVersioning",
    "disk_encryption_key": "diskEncryptionKey",
    "disk_size_gb": "diskSizeGb",
    "dispatch_rules": "dispatchRules",
    "display_name": "displayName",
    "distribution_policy_zones": "distributionPolicyZones",
    "dns_address": "dnsAddress",
    "dns_beta_custom_endpoint": "dnsBetaCustomEndpoint",
    "dns_custom_endpoint": "dnsCustomEndpoint",
    "dns_name": "dnsName",
    "dnssec_config": "dnssecConfig",
    "domain_name": "domainName",
    "drain_nat_ips": "drainNatIps",
    "driver_controls_files_uri": "driverControlsFilesUri",
    "driver_output_resource_uri": "driverOutputResourceUri",
    "edge_availability_domain": "edgeAvailabilityDomain",
    "enable_binary_authorization": "enableBinaryAuthorization",
    "enable_cdn": "enableCdn",
    "enable_flow_logs": "enableFlowLogs",
    "enable_history_import": "enableHistoryImport",
    "enable_inbound_forwarding": "enableInboundForwarding",
    "enable_intranode_visibility": "enableIntranodeVisibility",
    "enable_kubernetes_alpha": "enableKubernetesAlpha",
    "enable_legacy_abac": "enableLegacyAbac",
    "enable_logging": "enableLogging",
    "enable_shielded_nodes": "enableShieldedNodes",
    "enable_tpu": "enableTpu",
    "enable_update_create": "enableUpdateCreate",
    "enabled_features": "enabledFeatures",
    "entity_id": "entityId",
    "entry_point": "entryPoint",
    "env_variables": "envVariables",
    "environment_variables": "environmentVariables",
    "event_notification_config": "eventNotificationConfig",
    "event_notification_configs": "eventNotificationConfigs",
    "event_trigger": "eventTrigger",
    "event_types": "eventTypes",
    "expiration_policy": "expirationPolicy",
    "expiration_time": "expirationTime",
    "expire_time": "expireTime",
    "export_custom_routes": "exportCustomRoutes",
    "export_to_security_command_center": "exportToSecurityCommandCenter",
    "external_data_configuration": "externalDataConfiguration",
    "failover_policy": "failoverPolicy",
    "failover_ratio": "failoverRatio",
    "feature_settings": "featureSettings",
    "fhir_store_id": "fhirStoreId",
    "file_shares": "fileShares",
    "filestore_custom_endpoint": "filestoreCustomEndpoint",
    "firestore_custom_endpoint": "firestoreCustomEndpoint",
    "first_ip_address": "firstIpAddress",
    "folder_id": "folderId",
    "force_delete": "forceDelete",
    "force_destroy": "forceDestroy",
    "forwarding_config": "forwardingConfig",
    "friendly_name": "friendlyName",
    "gateway_address": "gatewayAddress",
    "gateway_id": "gatewayId",
    "gateway_ipv4": "gatewayIpv4",
    "gcr_domain": "gcrDomain",
    "global_policy_evaluation_mode": "globalPolicyEvaluationMode",
    "google_reference_id": "googleReferenceId",
    "grpc_config": "grpcConfig",
    "guest_accelerators": "guestAccelerators",
    "guest_os_features": "guestOsFeatures",
    "hadoop_config": "hadoopConfig",
    "health_checks": "healthChecks",
    "healthcare_custom_endpoint": "healthcareCustomEndpoint",
    "healthy_threshold": "healthyThreshold",
    "hive_config": "hiveConfig",
    "hl7_v2_store_id": "hl7V2StoreId",
    "host_project": "hostProject",
    "host_rules": "hostRules",
    "http2_health_check": "http2HealthCheck",
    "http_check": "httpCheck",
    "http_config": "httpConfig",
    "http_enabled_state": "httpEnabledState",
    "http_health_check": "httpHealthCheck",
    "http_target": "httpTarget",
    "https_health_check": "httpsHealthCheck",
    "https_trigger_url": "httpsTriggerUrl",
    "iam_credentials_custom_endpoint": "iamCredentialsCustomEndpoint",
    "iam_custom_endpoint": "iamCustomEndpoint",
    "iap_custom_endpoint": "iapCustomEndpoint",
    "icmp_idle_timeout_sec": "icmpIdleTimeoutSec",
    "ignore_warnings": "ignoreWarnings",
    "ignored_files": "ignoredFiles",
    "ike_version": "ikeVersion",
    "import_custom_routes": "importCustomRoutes",
    "include_children": "includeChildren",
    "included_files": "includedFiles",
    "initial_node_count": "initialNodeCount",
    "instance_class": "instanceClass",
    "instance_description": "instanceDescription",
    "instance_group": "instanceGroup",
    "instance_group_urls": "instanceGroupUrls",
    "instance_id": "instanceId",
    "instance_name": "instanceName",
    "instance_type": "instanceType",
    "interconnect_attachment": "interconnectAttachment",
    "internal_checkers": "internalCheckers",
    "ip_address": "ipAddress",
    "ip_addresses": "ipAddresses",
    "ip_allocation_policy": "ipAllocationPolicy",
    "ip_cidr_range": "ipCidrRange",
    "ip_configuration": "ipConfiguration",
    "ip_protocol": "ipProtocol",
    "ip_range": "ipRange",
    "ip_version": "ipVersion",
    "ipv4_range": "ipv4Range",
    "is_cluster": "isCluster",
    "is_internal": "isInternal",
    "job_id": "jobId",
    "key_algorithm": "keyAlgorithm",
    "key_ring": "keyRing",
    "key_ring_id": "keyRingId",
    "key_value": "keyValue",
    "kms_custom_endpoint": "kmsCustomEndpoint",
    "kms_key_name": "kmsKeyName",
    "label_extractors": "labelExtractors",
    "label_fingerprint": "labelFingerprint",
    "last_attach_timestamp": "lastAttachTimestamp",
    "last_detach_timestamp": "lastDetachTimestamp",
    "last_modification_time": "lastModificationTime",
    "last_modified_time": "lastModifiedTime",
    "lifecycle_rules": "lifecycleRules",
    "lifecycle_state": "lifecycleState",
    "list_policy": "listPolicy",
    "load_balancing_scheme": "loadBalancingScheme",
    "local_traffic_selectors": "localTrafficSelectors",
    "locality_lb_policy": "localityLbPolicy",
    "location_id": "locationId",
    "log_config": "logConfig",
    "log_level": "logLevel",
    "logging_custom_endpoint": "loggingCustomEndpoint",
    "logging_service": "loggingService",
    "machine_type": "machineType",
    "maintenance_policy": "maintenancePolicy",
    "managed_zone": "managedZone",
    "map_id": "mapId",
    "master_auth": "masterAuth",
    "master_authorized_networks_config": "masterAuthorizedNetworksConfig",
    "master_instance_name": "masterInstanceName",
    "master_version": "masterVersion",
    "max_ages": "maxAges",
    "max_instances": "maxInstances",
    "max_pods_per_node": "maxPodsPerNode",
    "max_qps": "maxQps",
    "max_throughput": "maxThroughput",
    "max_versions": "maxVersions",
    "max_workers": "maxWorkers",
    "memory_size_gb": "memorySizeGb",
    "message_retention_duration": "messageRetentionDuration",
    "message_storage_policy": "messageStoragePolicy",
    "metadata_filters": "metadataFilters",
    "metadata_fingerprint": "metadataFingerprint",
    "metadata_startup_script": "metadataStartupScript",
    "metric_descriptor": "metricDescriptor",
    "min_cpu_platform": "minCpuPlatform",
    "min_master_version": "minMasterVersion",
    "min_ports_per_vm": "minPortsPerVm",
    "min_throughput": "minThroughput",
    "min_tls_version": "minTlsVersion",
    "ml_engine_custom_endpoint": "mlEngineCustomEndpoint",
    "monitored_resource": "monitoredResource",
    "monitoring_custom_endpoint": "monitoringCustomEndpoint",
    "monitoring_service": "monitoringService",
    "mqtt_config": "mqttConfig",
    "mqtt_enabled_state": "mqttEnabledState",
    "multi_cluster_routing_use_any": "multiClusterRoutingUseAny",
    "name_prefix": "namePrefix",
    "name_servers": "nameServers",
    "named_ports": "namedPorts",
    "nat_ip_allocate_option": "natIpAllocateOption",
    "nat_ips": "natIps",
    "nat_policy": "natPolicy",
    "network_endpoint_group": "networkEndpointGroup",
    "network_endpoint_type": "networkEndpointType",
    "network_endpoints": "networkEndpoints",
    "network_interfaces": "networkInterfaces",
    "network_policy": "networkPolicy",
    "network_tier": "networkTier",
    "next_hop_gateway": "nextHopGateway",
    "next_hop_ilb": "nextHopIlb",
    "next_hop_instance": "nextHopInstance",
    "next_hop_instance_zone": "nextHopInstanceZone",
    "next_hop_ip": "nextHopIp",
    "next_hop_network": "nextHopNetwork",
    "next_hop_vpn_tunnel": "nextHopVpnTunnel",
    "node_affinity_labels": "nodeAffinityLabels",
    "node_config": "nodeConfig",
    "node_count": "nodeCount",
    "node_locations": "nodeLocations",
    "node_pools": "nodePools",
    "node_template": "nodeTemplate",
    "node_type": "nodeType",
    "node_type_flexibility": "nodeTypeFlexibility",
    "node_version": "nodeVersion",
    "noop_on_destroy": "noopOnDestroy",
    "notification_channels": "notificationChannels",
    "notification_config": "notificationConfig",
    "num_bytes": "numBytes",
    "num_long_term_bytes": "numLongTermBytes",
    "num_nodes": "numNodes",
    "num_rows": "numRows",
    "object_name_prefix": "objectNamePrefix",
    "on_delete": "onDelete",
    "online_prediction_console_logging": "onlinePredictionConsoleLogging",
    "online_prediction_logging": "onlinePredictionLogging",
    "openapi_config": "openapiConfig",
    "org_id": "orgId",
    "outlier_detection": "outlierDetection",
    "output_name": "outputName",
    "override_strategy": "overrideStrategy",
    "pairing_key": "pairingKey",
    "parent_name": "parentName",
    "parser_config": "parserConfig",
    "partner_asn": "partnerAsn",
    "path_matchers": "pathMatchers",
    "payload_format": "payloadFormat",
    "peer_asn": "peerAsn",
    "peer_external_gateway": "peerExternalGateway",
    "peer_external_gateway_interface": "peerExternalGatewayInterface",
    "peer_gcp_gateway": "peerGcpGateway",
    "peer_ip": "peerIp",
    "peer_ip_address": "peerIpAddress",
    "peer_network": "peerNetwork",
    "peering_config": "peeringConfig",
    "perimeter_type": "perimeterType",
    "pgp_key": "pgpKey",
    "physical_block_size_bytes": "physicalBlockSizeBytes",
    "pig_config": "pigConfig",
    "pod_security_policy_config": "podSecurityPolicyConfig",
    "policy_data": "policyData",
    "policy_id": "policyId",
    "port_name": "portName",
    "port_range": "portRange",
    "predefined_acl": "predefinedAcl",
    "prefix_length": "prefixLength",
    "private_cluster_config": "privateClusterConfig",
    "private_interconnect_info": "privateInterconnectInfo",
    "private_ip_address": "privateIpAddress",
    "private_ip_google_access": "privateIpGoogleAccess",
    "private_key": "privateKey",
    "private_key_encrypted": "privateKeyEncrypted",
    "private_key_fingerprint": "privateKeyFingerprint",
    "private_key_type": "privateKeyType",
    "private_visibility_config": "privateVisibilityConfig",
    "project_id": "projectId",
    "project_team": "projectTeam",
    "protoc_output_base64": "protocOutputBase64",
    "proxy_header": "proxyHeader",
    "proxy_id": "proxyId",
    "public_ip_address": "publicIpAddress",
    "public_key": "publicKey",
    "public_key_type": "publicKeyType",
    "pubsub_custom_endpoint": "pubsubCustomEndpoint",
    "pubsub_target": "pubsubTarget",
    "pubsub_topic_name": "pubsubTopicName",
    "push_config": "pushConfig",
    "pyspark_config": "pysparkConfig",
    "query_scope": "queryScope",
    "quic_override": "quicOverride",
    "raw_disk": "rawDisk",
    "redis_configs": "redisConfigs",
    "redis_custom_endpoint": "redisCustomEndpoint",
    "redis_version": "redisVersion",
    "redundancy_type": "redundancyType",
    "release_channel": "releaseChannel",
    "remote_traffic_selectors": "remoteTrafficSelectors",
    "remove_default_node_pool": "removeDefaultNodePool",
    "replica_configuration": "replicaConfiguration",
    "replica_zones": "replicaZones",
    "request_path": "requestPath",
    "requester_pays": "requesterPays",
    "reserved_ip_range": "reservedIpRange",
    "reserved_peering_ranges": "reservedPeeringRanges",
    "resource_group": "resourceGroup",
    "resource_labels": "resourceLabels",
    "resource_manager_custom_endpoint": "resourceManagerCustomEndpoint",
    "resource_manager_v2beta1_custom_endpoint": "resourceManagerV2beta1CustomEndpoint",
    "resource_policies": "resourcePolicies",
    "resource_records": "resourceRecords",
    "resource_usage_export_config": "resourceUsageExportConfig",
    "restore_policy": "restorePolicy",
    "retain_acked_messages": "retainAckedMessages",
    "retention_policy": "retentionPolicy",
    "retry_config": "retryConfig",
    "role_entities": "roleEntities",
    "role_id": "roleId",
    "rotation_period": "rotationPeriod",
    "routing_mode": "routingMode",
    "runtime_api_version": "runtimeApiVersion",
    "runtime_config_custom_endpoint": "runtimeConfigCustomEndpoint",
    "runtimeconfig_custom_endpoint": "runtimeconfigCustomEndpoint",
    "scheduling_config": "schedulingConfig",
    "scratch_disks": "scratchDisks",
    "secondary_ip_ranges": "secondaryIpRanges",
    "secondary_worker_config": "secondaryWorkerConfig",
    "security_center_custom_endpoint": "securityCenterCustomEndpoint",
    "security_policy": "securityPolicy",
    "security_scanner_custom_endpoint": "securityScannerCustomEndpoint",
    "selected_regions": "selectedRegions",
    "self_link": "selfLink",
    "server_binding": "serverBinding",
    "server_ca_cert": "serverCaCert",
    "service_account": "serviceAccount",
    "service_account_email": "serviceAccountEmail",
    "service_account_email_address": "serviceAccountEmailAddress",
    "service_account_id": "serviceAccountId",
    "service_label": "serviceLabel",
    "service_management_custom_endpoint": "serviceManagementCustomEndpoint",
    "service_name": "serviceName",
    "service_networking_custom_endpoint": "serviceNetworkingCustomEndpoint",
    "service_project": "serviceProject",
    "service_usage_custom_endpoint": "serviceUsageCustomEndpoint",
    "services_ipv4_cidr": "servicesIpv4Cidr",
    "serving_status": "servingStatus",
    "session_affinity": "sessionAffinity",
    "sha1_fingerprint": "sha1Fingerprint",
    "shared_secret": "sharedSecret",
    "shared_secret_hash": "sharedSecretHash",
    "shielded_instance_config": "shieldedInstanceConfig",
    "single_cluster_routing": "singleClusterRouting",
    "skip_delete": "skipDelete",
    "snapshot_encryption_key": "snapshotEncryptionKey",
    "snapshot_id": "snapshotId",
    "snapshot_schedule_policy": "snapshotSchedulePolicy",
    "source_archive_bucket": "sourceArchiveBucket",
    "source_archive_object": "sourceArchiveObject",
    "source_disk": "sourceDisk",
    "source_disk_encryption_key": "sourceDiskEncryptionKey",
    "source_disk_link": "sourceDiskLink",
    "source_image_encryption_key": "sourceImageEncryptionKey",
    "source_image_id": "sourceImageId",
    "source_instance_template": "sourceInstanceTemplate",
    "source_range": "sourceRange",
    "source_ranges": "sourceRanges",
    "source_repo_custom_endpoint": "sourceRepoCustomEndpoint",
    "source_repository": "sourceRepository",
    "source_service_accounts": "sourceServiceAccounts",
    "source_snapshot_encryption_key": "sourceSnapshotEncryptionKey",
    "source_snapshot_id": "sourceSnapshotId",
    "source_subnetwork_ip_ranges_to_nat": "sourceSubnetworkIpRangesToNat",
    "source_tags": "sourceTags",
    "spanner_custom_endpoint": "spannerCustomEndpoint",
    "spark_config": "sparkConfig",
    "sparksql_config": "sparksqlConfig",
    "specific_reservation": "specificReservation",
    "specific_reservation_required": "specificReservationRequired",
    "split_keys": "splitKeys",
    "sql_custom_endpoint": "sqlCustomEndpoint",
    "ssl_certificates": "sslCertificates",
    "ssl_health_check": "sslHealthCheck",
    "ssl_policy": "sslPolicy",
    "ssl_settings": "sslSettings",
    "starting_urls": "startingUrls",
    "state_details": "stateDetails",
    "state_notification_config": "stateNotificationConfig",
    "storage_bytes": "storageBytes",
    "storage_class": "storageClass",
    "storage_custom_endpoint": "storageCustomEndpoint",
    "storage_transfer_custom_endpoint": "storageTransferCustomEndpoint",
    "subject_alternative_names": "subjectAlternativeNames",
    "table_id": "tableId",
    "tags_fingerprint": "tagsFingerprint",
    "target_platforms": "targetPlatforms",
    "target_pools": "targetPools",
    "target_service_accounts": "targetServiceAccounts",
    "target_size": "targetSize",
    "target_tags": "targetTags",
    "target_vpn_gateway": "targetVpnGateway",
    "tcp_check": "tcpCheck",
    "tcp_established_idle_timeout_sec": "tcpEstablishedIdleTimeoutSec",
    "tcp_health_check": "tcpHealthCheck",
    "tcp_transitory_idle_timeout_sec": "tcpTransitoryIdleTimeoutSec",
    "temp_gcs_location": "tempGcsLocation",
    "template_gcs_path": "templateGcsPath",
    "tensorflow_version": "tensorflowVersion",
    "time_partitioning": "timePartitioning",
    "time_zone": "timeZone",
    "timeout_sec": "timeoutSec",
    "tpu_custom_endpoint": "tpuCustomEndpoint",
    "tpu_ipv4_cidr_block": "tpuIpv4CidrBlock",
    "transfer_spec": "transferSpec",
    "trigger_http": "triggerHttp",
    "trigger_id": "triggerId",
    "trigger_template": "triggerTemplate",
    "tunnel_id": "tunnelId",
    "udp_idle_timeout_sec": "udpIdleTimeoutSec",
    "unhealthy_threshold": "unhealthyThreshold",
    "unique_id": "uniqueId",
    "unique_writer_identity": "uniqueWriterIdentity",
    "update_policy": "updatePolicy",
    "update_time": "updateTime",
    "uptime_check_id": "uptimeCheckId",
    "url_dispatch_rules": "urlDispatchRules",
    "url_map": "urlMap",
    "user_agent": "userAgent",
    "user_labels": "userLabels",
    "user_project_override": "userProjectOverride",
    "valid_after": "validAfter",
    "valid_before": "validBefore",
    "value_extractor": "valueExtractor",
    "verification_status": "verificationStatus",
    "version_id": "versionId",
    "version_template": "versionTemplate",
    "vertical_pod_autoscaling": "verticalPodAutoscaling",
    "vlan_tag8021q": "vlanTag8021q",
    "vpc_access_custom_endpoint": "vpcAccessCustomEndpoint",
    "vpc_connector": "vpcConnector",
    "vpn_gateway": "vpnGateway",
    "vpn_gateway_interface": "vpnGatewayInterface",
    "vpn_interfaces": "vpnInterfaces",
    "vpn_tunnel": "vpnTunnel",
    "wait_for_instances": "waitForInstances",
    "web_backend_service": "webBackendService",
    "worker_config": "workerConfig",
    "workload_identity_config": "workloadIdentityConfig",
    "writer_identity": "writerIdentity",
}

_CAMEL_TO_SNAKE_CASE_TABLE = {
    "acceleratorType": "accelerator_type",
    "accessContextManagerCustomEndpoint": "access_context_manager_custom_endpoint",
    "accessToken": "access_token",
    "accountId": "account_id",
    "ackDeadlineSeconds": "ack_deadline_seconds",
    "additionalZones": "additional_zones",
    "addonsConfig": "addons_config",
    "addressType": "address_type",
    "adminEnabled": "admin_enabled",
    "admissionWhitelistPatterns": "admission_whitelist_patterns",
    "advertiseMode": "advertise_mode",
    "advertisedGroups": "advertised_groups",
    "advertisedIpRanges": "advertised_ip_ranges",
    "advertisedRoutePriority": "advertised_route_priority",
    "affinityCookieTtlSec": "affinity_cookie_ttl_sec",
    "allPorts": "all_ports",
    "allowStoppingForUpdate": "allow_stopping_for_update",
    "alternativeLocationId": "alternative_location_id",
    "alternativeNameServerConfig": "alternative_name_server_config",
    "appEngineCustomEndpoint": "app_engine_custom_endpoint",
    "appEngineHttpTarget": "app_engine_http_target",
    "appId": "app_id",
    "appProfileId": "app_profile_id",
    "archiveSizeBytes": "archive_size_bytes",
    "attachedDisks": "attached_disks",
    "attestationAuthority": "attestation_authority",
    "attestationAuthorityNote": "attestation_authority_note",
    "auditLogConfigs": "audit_log_configs",
    "authDomain": "auth_domain",
    "authenticatorGroupsConfig": "authenticator_groups_config",
    "authorizedNetwork": "authorized_network",
    "autoCreateNetwork": "auto_create_network",
    "autoCreateRoutes": "auto_create_routes",
    "autoCreateSubnetworks": "auto_create_subnetworks",
    "autoHealingPolicies": "auto_healing_policies",
    "autoscalingPolicy": "autoscaling_policy",
    "availableMemoryMb": "available_memory_mb",
    "backendBucket": "backend_bucket",
    "backendService": "backend_service",
    "backupPool": "backup_pool",
    "baseInstanceName": "base_instance_name",
    "basicAlgorithm": "basic_algorithm",
    "bigQueryCustomEndpoint": "big_query_custom_endpoint",
    "bigqueryDataTransferCustomEndpoint": "bigquery_data_transfer_custom_endpoint",
    "bigtableCustomEndpoint": "bigtable_custom_endpoint",
    "billingAccount": "billing_account",
    "billingAccountId": "billing_account_id",
    "binaryAuthorizationCustomEndpoint": "binary_authorization_custom_endpoint",
    "blacklistPatterns": "blacklist_patterns",
    "booleanPolicy": "boolean_policy",
    "bootDisk": "boot_disk",
    "bucketName": "bucket_name",
    "bucketOptions": "bucket_options",
    "bucketPolicyOnly": "bucket_policy_only",
    "cacheControl": "cache_control",
    "canIpForward": "can_ip_forward",
    "candidateSubnets": "candidate_subnets",
    "cdnPolicy": "cdn_policy",
    "certSerialNumber": "cert_serial_number",
    "certificateId": "certificate_id",
    "checkIntervalSec": "check_interval_sec",
    "cidrBlock": "cidr_block",
    "circuitBreakers": "circuit_breakers",
    "cloudBillingCustomEndpoint": "cloud_billing_custom_endpoint",
    "cloudBuildCustomEndpoint": "cloud_build_custom_endpoint",
    "cloudFunction": "cloud_function",
    "cloudFunctionsCustomEndpoint": "cloud_functions_custom_endpoint",
    "cloudIotCustomEndpoint": "cloud_iot_custom_endpoint",
    "cloudRouterIpAddress": "cloud_router_ip_address",
    "cloudRunCustomEndpoint": "cloud_run_custom_endpoint",
    "cloudSchedulerCustomEndpoint": "cloud_scheduler_custom_endpoint",
    "clusterAdmissionRules": "cluster_admission_rules",
    "clusterAutoscaling": "cluster_autoscaling",
    "clusterConfig": "cluster_config",
    "clusterIpv4Cidr": "cluster_ipv4_cidr",
    "codeBucket": "code_bucket",
    "columnFamilies": "column_families",
    "columnFamily": "column_family",
    "commonName": "common_name",
    "composerCustomEndpoint": "composer_custom_endpoint",
    "computeBetaCustomEndpoint": "compute_beta_custom_endpoint",
    "computeCustomEndpoint": "compute_custom_endpoint",
    "configId": "config_id",
    "connectionDrainingTimeoutSec": "connection_draining_timeout_sec",
    "connectionName": "connection_name",
    "consistentHash": "consistent_hash",
    "containerAnalysisCustomEndpoint": "container_analysis_custom_endpoint",
    "containerBetaCustomEndpoint": "container_beta_custom_endpoint",
    "containerCustomEndpoint": "container_custom_endpoint",
    "contentDisposition": "content_disposition",
    "contentEncoding": "content_encoding",
    "contentLanguage": "content_language",
    "contentMatchers": "content_matchers",
    "contentType": "content_type",
    "cpuPlatform": "cpu_platform",
    "createTime": "create_time",
    "creationRecord": "creation_record",
    "creationTime": "creation_time",
    "creationTimestamp": "creation_timestamp",
    "cryptoKeyId": "crypto_key_id",
    "currentLocationId": "current_location_id",
    "customAttributes": "custom_attributes",
    "customFeatures": "custom_features",
    "customRequestHeaders": "custom_request_headers",
    "customerRouterIpAddress": "customer_router_ip_address",
    "dataRefreshWindowDays": "data_refresh_window_days",
    "dataSourceId": "data_source_id",
    "databaseEncryption": "database_encryption",
    "databaseVersion": "database_version",
    "dataflowCustomEndpoint": "dataflow_custom_endpoint",
    "dataprocBetaCustomEndpoint": "dataproc_beta_custom_endpoint",
    "dataprocCustomEndpoint": "dataproc_custom_endpoint",
    "datasetId": "dataset_id",
    "defaultAcl": "default_acl",
    "defaultAdmissionRule": "default_admission_rule",
    "defaultBucket": "default_bucket",
    "defaultEncryptionConfiguration": "default_encryption_configuration",
    "defaultHostname": "default_hostname",
    "defaultMaxPodsPerNode": "default_max_pods_per_node",
    "defaultPartitionExpirationMs": "default_partition_expiration_ms",
    "defaultPort": "default_port",
    "defaultService": "default_service",
    "defaultTableExpirationMs": "default_table_expiration_ms",
    "defaultVersion": "default_version",
    "deleteContentsOnDestroy": "delete_contents_on_destroy",
    "deleteDefaultRoutesOnCreate": "delete_default_routes_on_create",
    "deleteServiceOnDestroy": "delete_service_on_destroy",
    "deletionProtection": "deletion_protection",
    "deletionTime": "deletion_time",
    "destRange": "dest_range",
    "destinationDatasetId": "destination_dataset_id",
    "destinationRanges": "destination_ranges",
    "detailedStatus": "detailed_status",
    "detectMd5hash": "detect_md5hash",
    "deviceName": "device_name",
    "dicomStoreId": "dicom_store_id",
    "disableDependentServices": "disable_dependent_services",
    "disableOnDestroy": "disable_on_destroy",
    "disableReferentialIntegrity": "disable_referential_integrity",
    "disableResourceVersioning": "disable_resource_versioning",
    "diskEncryptionKey": "disk_encryption_key",
    "diskSizeGb": "disk_size_gb",
    "dispatchRules": "dispatch_rules",
    "displayName": "display_name",
    "distributionPolicyZones": "distribution_policy_zones",
    "dnsAddress": "dns_address",
    "dnsBetaCustomEndpoint": "dns_beta_custom_endpoint",
    "dnsCustomEndpoint": "dns_custom_endpoint",
    "dnsName": "dns_name",
    "dnssecConfig": "dnssec_config",
    "domainName": "domain_name",
    "drainNatIps": "drain_nat_ips",
    "driverControlsFilesUri": "driver_controls_files_uri",
    "driverOutputResourceUri": "driver_output_resource_uri",
    "edgeAvailabilityDomain": "edge_availability_domain",
    "enableBinaryAuthorization": "enable_binary_authorization",
    "enableCdn": "enable_cdn",
    "enableFlowLogs": "enable_flow_logs",
    "enableHistoryImport": "enable_history_import",
    "enableInboundForwarding": "enable_inbound_forwarding",
    "enableIntranodeVisibility": "enable_intranode_visibility",
    "enableKubernetesAlpha": "enable_kubernetes_alpha",
    "enableLegacyAbac": "enable_legacy_abac",
    "enableLogging": "enable_logging",
    "enableShieldedNodes": "enable_shielded_nodes",
    "enableTpu": "enable_tpu",
    "enableUpdateCreate": "enable_update_create",
    "enabledFeatures": "enabled_features",
    "entityId": "entity_id",
    "entryPoint": "entry_point",
    "envVariables": "env_variables",
    "environmentVariables": "environment_variables",
    "eventNotificationConfig": "event_notification_config",
    "eventNotificationConfigs": "event_notification_configs",
    "eventTrigger": "event_trigger",
    "eventTypes": "event_types",
    "expirationPolicy": "expiration_policy",
    "expirationTime": "expiration_time",
    "expireTime": "expire_time",
    "exportCustomRoutes": "export_custom_routes",
    "exportToSecurityCommandCenter": "export_to_security_command_center",
    "externalDataConfiguration": "external_data_configuration",
    "failoverPolicy": "failover_policy",
    "failoverRatio": "failover_ratio",
    "featureSettings": "feature_settings",
    "fhirStoreId": "fhir_store_id",
    "fileShares": "file_shares",
    "filestoreCustomEndpoint": "filestore_custom_endpoint",
    "firestoreCustomEndpoint": "firestore_custom_endpoint",
    "firstIpAddress": "first_ip_address",
    "folderId": "folder_id",
    "forceDelete": "force_delete",
    "forceDestroy": "force_destroy",
    "forwardingConfig": "forwarding_config",
    "friendlyName": "friendly_name",
    "gatewayAddress": "gateway_address",
    "gatewayId": "gateway_id",
    "gatewayIpv4": "gateway_ipv4",
    "gcrDomain": "gcr_domain",
    "globalPolicyEvaluationMode": "global_policy_evaluation_mode",
    "googleReferenceId": "google_reference_id",
    "grpcConfig": "grpc_config",
    "guestAccelerators": "guest_accelerators",
    "guestOsFeatures": "guest_os_features",
    "hadoopConfig": "hadoop_config",
    "healthChecks": "health_checks",
    "healthcareCustomEndpoint": "healthcare_custom_endpoint",
    "healthyThreshold": "healthy_threshold",
    "hiveConfig": "hive_config",
    "hl7V2StoreId": "hl7_v2_store_id",
    "hostProject": "host_project",
    "hostRules": "host_rules",
    "http2HealthCheck": "http2_health_check",
    "httpCheck": "http_check",
    "httpConfig": "http_config",
    "httpEnabledState": "http_enabled_state",
    "httpHealthCheck": "http_health_check",
    "httpTarget": "http_target",
    "httpsHealthCheck": "https_health_check",
    "httpsTriggerUrl": "https_trigger_url",
    "iamCredentialsCustomEndpoint": "iam_credentials_custom_endpoint",
    "iamCustomEndpoint": "iam_custom_endpoint",
    "iapCustomEndpoint": "iap_custom_endpoint",
    "icmpIdleTimeoutSec": "icmp_idle_timeout_sec",
    "ignoreWarnings": "ignore_warnings",
    "ignoredFiles": "ignored_files",
    "ikeVersion": "ike_version",
    "importCustomRoutes": "import_custom_routes",
    "includeChildren": "include_children",
    "includedFiles": "included_files",
    "initialNodeCount": "initial_node_count",
    "instanceClass": "instance_class",
    "instanceDescription": "instance_description",
    "instanceGroup": "instance_group",
    "instanceGroupUrls": "instance_group_urls",
    "instanceId": "instance_id",
    "instanceName": "instance_name",
    "instanceType": "instance_type",
    "interconnectAttachment": "interconnect_attachment",
    "internalCheckers": "internal_checkers",
    "ipAddress": "ip_address",
    "ipAddresses": "ip_addresses",
    "ipAllocationPolicy": "ip_allocation_policy",
    "ipCidrRange": "ip_cidr_range",
    "ipConfiguration": "ip_configuration",
    "ipProtocol": "ip_protocol",
    "ipRange": "ip_range",
    "ipVersion": "ip_version",
    "ipv4Range": "ipv4_range",
    "isCluster": "is_cluster",
    "isInternal": "is_internal",
    "jobId": "job_id",
    "keyAlgorithm": "key_algorithm",
    "keyRing": "key_ring",
    "keyRingId": "key_ring_id",
    "keyValue": "key_value",
    "kmsCustomEndpoint": "kms_custom_endpoint",
    "kmsKeyName": "kms_key_name",
    "labelExtractors": "label_extractors",
    "labelFingerprint": "label_fingerprint",
    "lastAttachTimestamp": "last_attach_timestamp",
    "lastDetachTimestamp": "last_detach_timestamp",
    "lastModificationTime": "last_modification_time",
    "lastModifiedTime": "last_modified_time",
    "lifecycleRules": "lifecycle_rules",
    "lifecycleState": "lifecycle_state",
    "listPolicy": "list_policy",
    "loadBalancingScheme": "load_balancing_scheme",
    "localTrafficSelectors": "local_traffic_selectors",
    "localityLbPolicy": "locality_lb_policy",
    "locationId": "location_id",
    "logConfig": "log_config",
    "logLevel": "log_level",
    "loggingCustomEndpoint": "logging_custom_endpoint",
    "loggingService": "logging_service",
    "machineType": "machine_type",
    "maintenancePolicy": "maintenance_policy",
    "managedZone": "managed_zone",
    "mapId": "map_id",
    "masterAuth": "master_auth",
    "masterAuthorizedNetworksConfig": "master_authorized_networks_config",
    "masterInstanceName": "master_instance_name",
    "masterVersion": "master_version",
    "maxAges": "max_ages",
    "maxInstances": "max_instances",
    "maxPodsPerNode": "max_pods_per_node",
    "maxQps": "max_qps",
    "maxThroughput": "max_throughput",
    "maxVersions": "max_versions",
    "maxWorkers": "max_workers",
    "memorySizeGb": "memory_size_gb",
    "messageRetentionDuration": "message_retention_duration",
    "messageStoragePolicy": "message_storage_policy",
    "metadataFilters": "metadata_filters",
    "metadataFingerprint": "metadata_fingerprint",
    "metadataStartupScript": "metadata_startup_script",
    "metricDescriptor": "metric_descriptor",
    "minCpuPlatform": "min_cpu_platform",
    "minMasterVersion": "min_master_version",
    "minPortsPerVm": "min_ports_per_vm",
    "minThroughput": "min_throughput",
    "minTlsVersion": "min_tls_version",
    "mlEngineCustomEndpoint": "ml_engine_custom_endpoint",
    "monitoredResource": "monitored_resource",
    "monitoringCustomEndpoint": "monitoring_custom_endpoint",
    "monitoringService": "monitoring_service",
    "mqttConfig": "mqtt_config",
    "mqttEnabledState": "mqtt_enabled_state",
    "multiClusterRoutingUseAny": "multi_cluster_routing_use_any",
    "namePrefix": "name_prefix",
    "nameServers": "name_servers",
    "namedPorts": "named_ports",
    "natIpAllocateOption": "nat_ip_allocate_option",
    "natIps": "nat_ips",
    "natPolicy": "nat_policy",
    "networkEndpointGroup": "network_endpoint_group",
    "networkEndpointType": "network_endpoint_type",
    "networkEndpoints": "network_endpoints",
    "networkInterfaces": "network_interfaces",
    "networkPolicy": "network_policy",
    "networkTier": "network_tier",
    "nextHopGateway": "next_hop_gateway",
    "nextHopIlb": "next_hop_ilb",
    "nextHopInstance": "next_hop_instance",
    "nextHopInstanceZone": "next_hop_instance_zone",
    "nextHopIp": "next_hop_ip",
    "nextHopNetwork": "next_hop_network",
    "nextHopVpnTunnel": "next_hop_vpn_tunnel",
    "nodeAffinityLabels": "node_affinity_labels",
    "nodeConfig": "node_config",
    "nodeCount": "node_count",
    "nodeLocations": "node_locations",
    "nodePools": "node_pools",
    "nodeTemplate": "node_template",
    "nodeType": "node_type",
    "nodeTypeFlexibility": "node_type_flexibility",
    "nodeVersion": "node_version",
    "noopOnDestroy": "noop_on_destroy",
    "notificationChannels": "notification_channels",
    "notificationConfig": "notification_config",
    "numBytes": "num_bytes",
    "numLongTermBytes": "num_long_term_bytes",
    "numNodes": "num_nodes",
    "numRows": "num_rows",
    "objectNamePrefix": "object_name_prefix",
    "onDelete": "on_delete",
    "onlinePredictionConsoleLogging": "online_prediction_console_logging",
    "onlinePredictionLogging": "online_prediction_logging",
    "openapiConfig": "openapi_config",
    "orgId": "org_id",
    "outlierDetection": "outlier_detection",
    "outputName": "output_name",
    "overrideStrategy": "override_strategy",
    "pairingKey": "pairing_key",
    "parentName": "parent_name",
    "parserConfig": "parser_config",
    "partnerAsn": "partner_asn",
    "pathMatchers": "path_matchers",
    "payloadFormat": "payload_format",
    "peerAsn": "peer_asn",
    "peerExternalGateway": "peer_external_gateway",
    "peerExternalGatewayInterface": "peer_external_gateway_interface",
    "peerGcpGateway": "peer_gcp_gateway",
    "peerIp": "peer_ip",
    "peerIpAddress": "peer_ip_address",
    "peerNetwork": "peer_network",
    "peeringConfig": "peering_config",
    "perimeterType": "perimeter_type",
    "pgpKey": "pgp_key",
    "physicalBlockSizeBytes": "physical_block_size_bytes",
    "pigConfig": "pig_config",
    "podSecurityPolicyConfig": "pod_security_policy_config",
    "policyData": "policy_data",
    "policyId": "policy_id",
    "portName": "port_name",
    "portRange": "port_range",
    "predefinedAcl": "predefined_acl",
    "prefixLength": "prefix_length",
    "privateClusterConfig": "private_cluster_config",
    "privateInterconnectInfo": "private_interconnect_info",
    "privateIpAddress": "private_ip_address",
    "privateIpGoogleAccess": "private_ip_google_access",
    "privateKey": "private_key",
    "privateKeyEncrypted": "private_key_encrypted",
    "privateKeyFingerprint": "private_key_fingerprint",
    "privateKeyType": "private_key_type",
    "privateVisibilityConfig": "private_visibility_config",
    "projectId": "project_id",
    "projectTeam": "project_team",
    "protocOutputBase64": "protoc_output_base64",
    "proxyHeader": "proxy_header",
    "proxyId": "proxy_id",
    "publicIpAddress": "public_ip_address",
    "publicKey": "public_key",
    "publicKeyType": "public_key_type",
    "pubsubCustomEndpoint": "pubsub_custom_endpoint",
    "pubsubTarget": "pubsub_target",
    "pubsubTopicName": "pubsub_topic_name",
    "pushConfig": "push_config",
    "pysparkConfig": "pyspark_config",
    "queryScope": "query_scope",
    "quicOverride": "quic_override",
    "rawDisk": "raw_disk",
    "redisConfigs": "redis_configs",
    "redisCustomEndpoint": "redis_custom_endpoint",
    "redisVersion": "redis_version",
    "redundancyType": "redundancy_type",
    "releaseChannel": "release_channel",
    "remoteTrafficSelectors": "remote_traffic_selectors",
    "removeDefaultNodePool": "remove_default_node_pool",
    "replicaConfiguration": "replica_configuration",
    "replicaZones": "replica_zones",
    "requestPath": "request_path",
    "requesterPays": "requester_pays",
    "reservedIpRange": "reserved_ip_range",
    "reservedPeeringRanges": "reserved_peering_ranges",
    "resourceGroup": "resource_group",
    "resourceLabels": "resource_labels",
    "resourceManagerCustomEndpoint": "resource_manager_custom_endpoint",
    "resourceManagerV2beta1CustomEndpoint": "resource_manager_v2beta1_custom_endpoint",
    "resourcePolicies": "resource_policies",
    "resourceRecords": "resource_records",
    "resourceUsageExportConfig": "resource_usage_export_config",
    "restorePolicy": "restore_policy",
    "retainAckedMessages": "retain_acked_messages",
    "retentionPolicy": "retention_policy",
    "retryConfig": "retry_config",
    "roleEntities": "role_entities",
    "roleId": "role_id",
    "rotationPeriod": "rotation_period",
    "routingMode": "routing_mode",
    "runtimeApiVersion": "runtime_api_version",
    "runtimeConfigCustomEndpoint": "runtime_config_custom_endpoint",
    "runtimeconfigCustomEndpoint": "runtimeconfig_custom_endpoint",
    "schedulingConfig": "scheduling_config",
    "scratchDisks": "scratch_disks",
    "secondaryIpRanges": "secondary_ip_ranges",
    "secondaryWorkerConfig": "secondary_worker_config",
    "securityCenterCustomEndpoint": "security_center_custom_endpoint",
    "securityPolicy": "security_policy",
    "securityScannerCustomEndpoint": "security_scanner_custom_endpoint",
    "selectedRegions": "selected_regions",
    "selfLink": "self_link",
    "serverBinding": "server_binding",
    "serverCaCert": "server_ca_cert",
    "serviceAccount": "service_account",
    "serviceAccountEmail": "service_account_email",
    "serviceAccountEmailAddress": "service_account_email_address",
    "serviceAccountId": "service_account_id",
    "serviceLabel": "service_label",
    "serviceManagementCustomEndpoint": "service_management_custom_endpoint",
    "serviceName": "service_name",
    "serviceNetworkingCustomEndpoint": "service_networking_custom_endpoint",
    "serviceProject": "service_project",
    "serviceUsageCustomEndpoint": "service_usage_custom_endpoint",
    "servicesIpv4Cidr": "services_ipv4_cidr",
    "servingStatus": "serving_status",
    "sessionAffinity": "session_affinity",
    "sha1Fingerprint": "sha1_fingerprint",
    "sharedSecret": "shared_secret",
    "sharedSecretHash": "shared_secret_hash",
    "shieldedInstanceConfig": "shielded_instance_config",
    "singleClusterRouting": "single_cluster_routing",
    "skipDelete": "skip_delete",
    "snapshotEncryptionKey": "snapshot_encryption_key",
    "snapshotId": "snapshot_id",
    "snapshotSchedulePolicy": "snapshot_schedule_policy",
    "sourceArchiveBucket": "source_archive_bucket",
    "sourceArchiveObject": "source_archive_object",
    "sourceDisk": "source_disk",
    "sourceDiskEncryptionKey": "source_disk_encryption_key",
    "sourceDiskLink": "source_disk_link",
    "sourceImageEncryptionKey": "source_image_encryption_key",
    "sourceImageId": "source_image_id",
    "sourceInstanceTemplate": "source_instance_template",
    "sourceRange": "source_range",
    "sourceRanges": "source_ranges",
    "sourceRepoCustomEndpoint": "source_repo_custom_endpoint",
    "sourceRepository": "source_repository",
    "sourceServiceAccounts": "source_service_accounts",
    "sourceSnapshotEncryptionKey": "source_snapshot_encryption_key",
    "sourceSnapshotId": "source_snapshot_id",
    "sourceSubnetworkIpRangesToNat": "source_subnetwork_ip_ranges_to_nat",
    "sourceTags": "source_tags",
    "spannerCustomEndpoint": "spanner_custom_endpoint",
    "sparkConfig": "spark_config",
    "sparksqlConfig": "sparksql_config",
    "specificReservation": "specific_reservation",
    "specificReservationRequired": "specific_reservation_required",
    "splitKeys": "split_keys",
    "sqlCustomEndpoint": "sql_custom_endpoint",
    "sslCertificates": "ssl_certificates",
    "sslHealthCheck": "ssl_health_check",
    "sslPolicy": "ssl_policy",
    "sslSettings": "ssl_settings",
    "startingUrls": "starting_urls",
    "stateDetails": "state_details",
    "stateNotificationConfig": "state_notification_config",
    "storageBytes": "storage_bytes",
    "storageClass": "storage_class",
    "storageCustomEndpoint": "storage_custom_endpoint",
    "storageTransferCustomEndpoint": "storage_transfer_custom_endpoint",
    "subjectAlternativeNames": "subject_alternative_names",
    "tableId": "table_id",
    "tagsFingerprint": "tags_fingerprint",
    "targetPlatforms": "target_platforms",
    "targetPools": "target_pools",
    "targetServiceAccounts": "target_service_accounts",
    "targetSize": "target_size",
    "targetTags": "target_tags",
    "targetVpnGateway": "target_vpn_gateway",
    "tcpCheck": "tcp_check",
    "tcpEstablishedIdleTimeoutSec": "tcp_established_idle_timeout_sec",
    "tcpHealthCheck": "tcp_health_check",
    "tcpTransitoryIdleTimeoutSec": "tcp_transitory_idle_timeout_sec",
    "tempGcsLocation": "temp_gcs_location",
    "templateGcsPath": "template_gcs_path",
    "tensorflowVersion": "tensorflow_version",
    "timePartitioning": "time_partitioning",
    "timeZone": "time_zone",
    "timeoutSec": "timeout_sec",
    "tpuCustomEndpoint": "tpu_custom_endpoint",
    "tpuIpv4CidrBlock": "tpu_ipv4_cidr_block",
    "transferSpec": "transfer_spec",
    "triggerHttp": "trigger_http",
    "triggerId": "trigger_id",
    "triggerTemplate": "trigger_template",
    "tunnelId": "tunnel_id",
    "udpIdleTimeoutSec": "udp_idle_timeout_sec",
    "unhealthyThreshold": "unhealthy_threshold",
    "uniqueId": "unique_id",
    "uniqueWriterIdentity": "unique_writer_identity",
    "updatePolicy": "update_policy",
    "updateTime": "update_time",
    "uptimeCheckId": "uptime_check_id",
    "urlDispatchRules": "url_dispatch_rules",
    "urlMap": "url_map",
    "userAgent": "user_agent",
    "userLabels": "user_labels",
    "userProjectOverride": "user_project_override",
    "validAfter": "valid_after",
    "validBefore": "valid_before",
    "valueExtractor": "value_extractor",
    "verificationStatus": "verification_status",
    "versionId": "version_id",
    "versionTemplate": "version_template",
    "verticalPodAutoscaling": "vertical_pod_autoscaling",
    "vlanTag8021q": "vlan_tag8021q",
    "vpcAccessCustomEndpoint": "vpc_access_custom_endpoint",
    "vpcConnector": "vpc_connector",
    "vpnGateway": "vpn_gateway",
    "vpnGatewayInterface": "vpn_gateway_interface",
    "vpnInterfaces": "vpn_interfaces",
    "vpnTunnel": "vpn_tunnel",
    "waitForInstances": "wait_for_instances",
    "webBackendService": "web_backend_service",
    "workerConfig": "worker_config",
    "workloadIdentityConfig": "workload_identity_config",
    "writerIdentity": "writer_identity",
}



# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import json
import warnings
import pulumi
import pulumi.runtime
from typing import Union
from .. import utilities, tables

class DomainMapping(pulumi.CustomResource):
    location: pulumi.Output[str]
    metadata: pulumi.Output[dict]
    name: pulumi.Output[str]
    project: pulumi.Output[str]
    spec: pulumi.Output[dict]
    status: pulumi.Output[dict]
    def __init__(__self__, resource_name, opts=None, location=None, metadata=None, name=None, project=None, spec=None, __props__=None, __name__=None, __opts__=None):
        """
        Create a DomainMapping resource with the given unique name, props, and options.
        
        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        
        The **metadata** object supports the following:
        
          * `annotations` (`pulumi.Input[dict]`)
          * `generation` (`pulumi.Input[float]`)
          * `labels` (`pulumi.Input[dict]`)
          * `namespace` (`pulumi.Input[str]`)
          * `resourceVersion` (`pulumi.Input[str]`)
          * `self_link` (`pulumi.Input[str]`)
          * `uid` (`pulumi.Input[str]`)
        
        The **spec** object supports the following:
        
          * `certificateMode` (`pulumi.Input[str]`)
          * `forceOverride` (`pulumi.Input[bool]`)
          * `routeName` (`pulumi.Input[str]`)

        > This content is derived from https://github.com/terraform-providers/terraform-provider-google/blob/master/website/docs/r/cloud_run_domain_mapping.html.markdown.
        """
        if __name__ is not None:
            warnings.warn("explicit use of __name__ is deprecated", DeprecationWarning)
            resource_name = __name__
        if __opts__ is not None:
            warnings.warn("explicit use of __opts__ is deprecated, use 'opts' instead", DeprecationWarning)
            opts = __opts__
        if opts is None:
            opts = pulumi.ResourceOptions()
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.version is None:
            opts.version = utilities.get_version()
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = dict()

            if location is None:
                raise TypeError("Missing required property 'location'")
            __props__['location'] = location
            if metadata is None:
                raise TypeError("Missing required property 'metadata'")
            __props__['metadata'] = metadata
            __props__['name'] = name
            __props__['project'] = project
            if spec is None:
                raise TypeError("Missing required property 'spec'")
            __props__['spec'] = spec
            __props__['status'] = None
        super(DomainMapping, __self__).__init__(
            'gcp:cloudrun/domainMapping:DomainMapping',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name, id, opts=None, location=None, metadata=None, name=None, project=None, spec=None, status=None):
        """
        Get an existing DomainMapping resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.
        
        :param str resource_name: The unique name of the resulting resource.
        :param str id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        
        The **metadata** object supports the following:
        
          * `annotations` (`pulumi.Input[dict]`)
          * `generation` (`pulumi.Input[float]`)
          * `labels` (`pulumi.Input[dict]`)
          * `namespace` (`pulumi.Input[str]`)
          * `resourceVersion` (`pulumi.Input[str]`)
          * `self_link` (`pulumi.Input[str]`)
          * `uid` (`pulumi.Input[str]`)
        
        The **spec** object supports the following:
        
          * `certificateMode` (`pulumi.Input[str]`)
          * `forceOverride` (`pulumi.Input[bool]`)
          * `routeName` (`pulumi.Input[str]`)
        
        The **status** object supports the following:
        
          * `conditions` (`pulumi.Input[list]`)
        
            * `message` (`pulumi.Input[str]`)
            * `reason` (`pulumi.Input[str]`)
            * `status` (`pulumi.Input[str]`)
            * `type` (`pulumi.Input[str]`)
        
          * `mappedRouteName` (`pulumi.Input[str]`)
          * `observedGeneration` (`pulumi.Input[float]`)
          * `resource_records` (`pulumi.Input[list]`)
        
            * `name` (`pulumi.Input[str]`)
            * `rrdata` (`pulumi.Input[str]`)
            * `type` (`pulumi.Input[str]`)

        > This content is derived from https://github.com/terraform-providers/terraform-provider-google/blob/master/website/docs/r/cloud_run_domain_mapping.html.markdown.
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = dict()
        __props__["location"] = location
        __props__["metadata"] = metadata
        __props__["name"] = name
        __props__["project"] = project
        __props__["spec"] = spec
        __props__["status"] = status
        return DomainMapping(resource_name, opts=opts, __props__=__props__)
    def translate_output_property(self, prop):
        return tables._CAMEL_TO_SNAKE_CASE_TABLE.get(prop) or prop

    def translate_input_property(self, prop):
        return tables._SNAKE_TO_CAMEL_CASE_TABLE.get(prop) or prop




# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import json
import warnings
import pulumi
import pulumi.runtime
from typing import Union
from .. import utilities, tables

class GetProjectServiceAccountResult:
    """
    A collection of values returned by getProjectServiceAccount.
    """
    def __init__(__self__, email_address=None, project=None, user_project=None, id=None):
        if email_address and not isinstance(email_address, str):
            raise TypeError("Expected argument 'email_address' to be a str")
        __self__.email_address = email_address
        """
        The email address of the service account. This value is often used to refer to the service account
        in order to grant IAM permissions.
        """
        if project and not isinstance(project, str):
            raise TypeError("Expected argument 'project' to be a str")
        __self__.project = project
        if user_project and not isinstance(user_project, str):
            raise TypeError("Expected argument 'user_project' to be a str")
        __self__.user_project = user_project
        if id and not isinstance(id, str):
            raise TypeError("Expected argument 'id' to be a str")
        __self__.id = id
        """
        id is the provider-assigned unique ID for this managed resource.
        """
class AwaitableGetProjectServiceAccountResult(GetProjectServiceAccountResult):
    # pylint: disable=using-constant-test
    def __await__(self):
        if False:
            yield self
        return GetProjectServiceAccountResult(
            email_address=self.email_address,
            project=self.project,
            user_project=self.user_project,
            id=self.id)

def get_project_service_account(project=None,user_project=None,opts=None):
    """
    Get the email address of a project's unique Google Cloud Storage service account.
    
    Each Google Cloud project has a unique service account for use with Google Cloud Storage. Only this
    special service account can be used to set up `storage.Notification` resources.
    
    For more information see
    [the API reference](https://cloud.google.com/storage/docs/json_api/v1/projects/serviceAccount).
    
    :param str project: The project the unique service account was created for. If it is not provided, the provider project is used.
    :param str user_project: The project the lookup originates from. This field is used if you are making the request
           from a different account than the one you are finding the service account for.

    > This content is derived from https://github.com/terraform-providers/terraform-provider-google/blob/master/website/docs/d/storage_project_service_account.html.markdown.
    """
    __args__ = dict()

    __args__['project'] = project
    __args__['userProject'] = user_project
    if opts is None:
        opts = pulumi.InvokeOptions()
    if opts.version is None:
        opts.version = utilities.get_version()
    __ret__ = pulumi.runtime.invoke('gcp:storage/getProjectServiceAccount:getProjectServiceAccount', __args__, opts=opts).value

    return AwaitableGetProjectServiceAccountResult(
        email_address=__ret__.get('emailAddress'),
        project=__ret__.get('project'),
        user_project=__ret__.get('userProject'),
        id=__ret__.get('id'))



# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import json
import warnings
import pulumi
import pulumi.runtime
from typing import Union
from .. import utilities, tables

class GetInstanceResult:
    """
    A collection of values returned by getInstance.
    """
    def __init__(__self__, allow_stopping_for_update=None, attached_disks=None, boot_disks=None, can_ip_forward=None, cpu_platform=None, deletion_protection=None, description=None, disks=None, guest_accelerators=None, hostname=None, instance_id=None, label_fingerprint=None, labels=None, machine_type=None, metadata=None, metadata_fingerprint=None, metadata_startup_script=None, min_cpu_platform=None, name=None, network_interfaces=None, project=None, schedulings=None, scratch_disks=None, self_link=None, service_accounts=None, shielded_instance_configs=None, tags=None, tags_fingerprint=None, zone=None, id=None):
        if allow_stopping_for_update and not isinstance(allow_stopping_for_update, bool):
            raise TypeError("Expected argument 'allow_stopping_for_update' to be a bool")
        __self__.allow_stopping_for_update = allow_stopping_for_update
        if attached_disks and not isinstance(attached_disks, list):
            raise TypeError("Expected argument 'attached_disks' to be a list")
        __self__.attached_disks = attached_disks
        """
        List of disks attached to the instance. Structure is documented below.
        """
        if boot_disks and not isinstance(boot_disks, list):
            raise TypeError("Expected argument 'boot_disks' to be a list")
        __self__.boot_disks = boot_disks
        """
        The boot disk for the instance. Structure is documented below.
        """
        if can_ip_forward and not isinstance(can_ip_forward, bool):
            raise TypeError("Expected argument 'can_ip_forward' to be a bool")
        __self__.can_ip_forward = can_ip_forward
        """
        Whether sending and receiving of packets with non-matching source or destination IPs is allowed.
        """
        if cpu_platform and not isinstance(cpu_platform, str):
            raise TypeError("Expected argument 'cpu_platform' to be a str")
        __self__.cpu_platform = cpu_platform
        """
        The CPU platform used by this instance.
        """
        if deletion_protection and not isinstance(deletion_protection, bool):
            raise TypeError("Expected argument 'deletion_protection' to be a bool")
        __self__.deletion_protection = deletion_protection
        """
        Whether deletion protection is enabled on this instance.
        """
        if description and not isinstance(description, str):
            raise TypeError("Expected argument 'description' to be a str")
        __self__.description = description
        """
        A brief description of the resource.
        """
        if disks and not isinstance(disks, list):
            raise TypeError("Expected argument 'disks' to be a list")
        __self__.disks = disks
        if guest_accelerators and not isinstance(guest_accelerators, list):
            raise TypeError("Expected argument 'guest_accelerators' to be a list")
        __self__.guest_accelerators = guest_accelerators
        """
        List of the type and count of accelerator cards attached to the instance. Structure is documented below.
        """
        if hostname and not isinstance(hostname, str):
            raise TypeError("Expected argument 'hostname' to be a str")
        __self__.hostname = hostname
        if instance_id and not isinstance(instance_id, str):
            raise TypeError("Expected argument 'instance_id' to be a str")
        __self__.instance_id = instance_id
        """
        The server-assigned unique identifier of this instance.
        """
        if label_fingerprint and not isinstance(label_fingerprint, str):
            raise TypeError("Expected argument 'label_fingerprint' to be a str")
        __self__.label_fingerprint = label_fingerprint
        """
        The unique fingerprint of the labels.
        """
        if labels and not isinstance(labels, dict):
            raise TypeError("Expected argument 'labels' to be a dict")
        __self__.labels = labels
        """
        A set of key/value label pairs assigned to the instance.
        """
        if machine_type and not isinstance(machine_type, str):
            raise TypeError("Expected argument 'machine_type' to be a str")
        __self__.machine_type = machine_type
        """
        The machine type to create.
        """
        if metadata and not isinstance(metadata, dict):
            raise TypeError("Expected argument 'metadata' to be a dict")
        __self__.metadata = metadata
        """
        Metadata key/value pairs made available within the instance.
        """
        if metadata_fingerprint and not isinstance(metadata_fingerprint, str):
            raise TypeError("Expected argument 'metadata_fingerprint' to be a str")
        __self__.metadata_fingerprint = metadata_fingerprint
        """
        The unique fingerprint of the metadata.
        """
        if metadata_startup_script and not isinstance(metadata_startup_script, str):
            raise TypeError("Expected argument 'metadata_startup_script' to be a str")
        __self__.metadata_startup_script = metadata_startup_script
        if min_cpu_platform and not isinstance(min_cpu_platform, str):
            raise TypeError("Expected argument 'min_cpu_platform' to be a str")
        __self__.min_cpu_platform = min_cpu_platform
        """
        The minimum CPU platform specified for the VM instance.
        """
        if name and not isinstance(name, str):
            raise TypeError("Expected argument 'name' to be a str")
        __self__.name = name
        if network_interfaces and not isinstance(network_interfaces, list):
            raise TypeError("Expected argument 'network_interfaces' to be a list")
        __self__.network_interfaces = network_interfaces
        """
        The networks attached to the instance. Structure is documented below.
        """
        if project and not isinstance(project, str):
            raise TypeError("Expected argument 'project' to be a str")
        __self__.project = project
        if schedulings and not isinstance(schedulings, list):
            raise TypeError("Expected argument 'schedulings' to be a list")
        __self__.schedulings = schedulings
        """
        The scheduling strategy being used by the instance.
        """
        if scratch_disks and not isinstance(scratch_disks, list):
            raise TypeError("Expected argument 'scratch_disks' to be a list")
        __self__.scratch_disks = scratch_disks
        """
        The scratch disks attached to the instance. Structure is documented below.
        """
        if self_link and not isinstance(self_link, str):
            raise TypeError("Expected argument 'self_link' to be a str")
        __self__.self_link = self_link
        """
        The URI of the created resource.
        """
        if service_accounts and not isinstance(service_accounts, list):
            raise TypeError("Expected argument 'service_accounts' to be a list")
        __self__.service_accounts = service_accounts
        """
        The service account to attach to the instance. Structure is documented below.
        """
        if shielded_instance_configs and not isinstance(shielded_instance_configs, list):
            raise TypeError("Expected argument 'shielded_instance_configs' to be a list")
        __self__.shielded_instance_configs = shielded_instance_configs
        """
        The shielded vm config being used by the instance. Structure is documented below.
        """
        if tags and not isinstance(tags, list):
            raise TypeError("Expected argument 'tags' to be a list")
        __self__.tags = tags
        """
        The list of tags attached to the instance.
        """
        if tags_fingerprint and not isinstance(tags_fingerprint, str):
            raise TypeError("Expected argument 'tags_fingerprint' to be a str")
        __self__.tags_fingerprint = tags_fingerprint
        """
        The unique fingerprint of the tags.
        """
        if zone and not isinstance(zone, str):
            raise TypeError("Expected argument 'zone' to be a str")
        __self__.zone = zone
        if id and not isinstance(id, str):
            raise TypeError("Expected argument 'id' to be a str")
        __self__.id = id
        """
        id is the provider-assigned unique ID for this managed resource.
        """
class AwaitableGetInstanceResult(GetInstanceResult):
    # pylint: disable=using-constant-test
    def __await__(self):
        if False:
            yield self
        return GetInstanceResult(
            allow_stopping_for_update=self.allow_stopping_for_update,
            attached_disks=self.attached_disks,
            boot_disks=self.boot_disks,
            can_ip_forward=self.can_ip_forward,
            cpu_platform=self.cpu_platform,
            deletion_protection=self.deletion_protection,
            description=self.description,
            disks=self.disks,
            guest_accelerators=self.guest_accelerators,
            hostname=self.hostname,
            instance_id=self.instance_id,
            label_fingerprint=self.label_fingerprint,
            labels=self.labels,
            machine_type=self.machine_type,
            metadata=self.metadata,
            metadata_fingerprint=self.metadata_fingerprint,
            metadata_startup_script=self.metadata_startup_script,
            min_cpu_platform=self.min_cpu_platform,
            name=self.name,
            network_interfaces=self.network_interfaces,
            project=self.project,
            schedulings=self.schedulings,
            scratch_disks=self.scratch_disks,
            self_link=self.self_link,
            service_accounts=self.service_accounts,
            shielded_instance_configs=self.shielded_instance_configs,
            tags=self.tags,
            tags_fingerprint=self.tags_fingerprint,
            zone=self.zone,
            id=self.id)

def get_instance(name=None,project=None,self_link=None,zone=None,opts=None):
    """
    Get information about a VM instance resource within GCE. For more information see
    [the official documentation](https://cloud.google.com/compute/docs/instances)
    and
    [API](https://cloud.google.com/compute/docs/reference/latest/instances).
    
    :param str name: The name of the instance. One of `name` or `self_link` must be provided.
    :param str project: The ID of the project in which the resource belongs.
           If `self_link` is provided, this value is ignored.  If neither `self_link`
           nor `project` are provided, the provider project is used.
    :param str self_link: The self link of the instance. One of `name` or `self_link` must be provided.
    :param str zone: The zone of the instance. If `self_link` is provided, this
           value is ignored.  If neither `self_link` nor `zone` are provided, the
           provider zone is used.

    > This content is derived from https://github.com/terraform-providers/terraform-provider-google/blob/master/website/docs/d/compute_instance.html.markdown.
    """
    __args__ = dict()

    __args__['name'] = name
    __args__['project'] = project
    __args__['selfLink'] = self_link
    __args__['zone'] = zone
    if opts is None:
        opts = pulumi.InvokeOptions()
    if opts.version is None:
        opts.version = utilities.get_version()
    __ret__ = pulumi.runtime.invoke('gcp:compute/getInstance:getInstance', __args__, opts=opts).value

    return AwaitableGetInstanceResult(
        allow_stopping_for_update=__ret__.get('allowStoppingForUpdate'),
        attached_disks=__ret__.get('attachedDisks'),
        boot_disks=__ret__.get('bootDisks'),
        can_ip_forward=__ret__.get('canIpForward'),
        cpu_platform=__ret__.get('cpuPlatform'),
        deletion_protection=__ret__.get('deletionProtection'),
        description=__ret__.get('description'),
        disks=__ret__.get('disks'),
        guest_accelerators=__ret__.get('guestAccelerators'),
        hostname=__ret__.get('hostname'),
        instance_id=__ret__.get('instanceId'),
        label_fingerprint=__ret__.get('labelFingerprint'),
        labels=__ret__.get('labels'),
        machine_type=__ret__.get('machineType'),
        metadata=__ret__.get('metadata'),
        metadata_fingerprint=__ret__.get('metadataFingerprint'),
        metadata_startup_script=__ret__.get('metadataStartupScript'),
        min_cpu_platform=__ret__.get('minCpuPlatform'),
        name=__ret__.get('name'),
        network_interfaces=__ret__.get('networkInterfaces'),
        project=__ret__.get('project'),
        schedulings=__ret__.get('schedulings'),
        scratch_disks=__ret__.get('scratchDisks'),
        self_link=__ret__.get('selfLink'),
        service_accounts=__ret__.get('serviceAccounts'),
        shielded_instance_configs=__ret__.get('shieldedInstanceConfigs'),
        tags=__ret__.get('tags'),
        tags_fingerprint=__ret__.get('tagsFingerprint'),
        zone=__ret__.get('zone'),
        id=__ret__.get('id'))



# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import json
import warnings
import pulumi
import pulumi.runtime
from typing import Union
from .. import utilities, tables

class Policy(pulumi.CustomResource):
    admission_whitelist_patterns: pulumi.Output[list]
    cluster_admission_rules: pulumi.Output[list]
    default_admission_rule: pulumi.Output[dict]
    description: pulumi.Output[str]
    global_policy_evaluation_mode: pulumi.Output[str]
    project: pulumi.Output[str]
    def __init__(__self__, resource_name, opts=None, admission_whitelist_patterns=None, cluster_admission_rules=None, default_admission_rule=None, description=None, global_policy_evaluation_mode=None, project=None, __props__=None, __name__=None, __opts__=None):
        """
        Create a Policy resource with the given unique name, props, and options.
        
        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        
        The **admission_whitelist_patterns** object supports the following:
        
          * `namePattern` (`pulumi.Input[str]`)
        
        The **cluster_admission_rules** object supports the following:
        
          * `cluster` (`pulumi.Input[str]`)
          * `enforcementMode` (`pulumi.Input[str]`)
          * `evaluationMode` (`pulumi.Input[str]`)
          * `requireAttestationsBies` (`pulumi.Input[list]`)
        
        The **default_admission_rule** object supports the following:
        
          * `enforcementMode` (`pulumi.Input[str]`)
          * `evaluationMode` (`pulumi.Input[str]`)
          * `requireAttestationsBies` (`pulumi.Input[list]`)

        > This content is derived from https://github.com/terraform-providers/terraform-provider-google/blob/master/website/docs/r/binary_authorization_policy.html.markdown.
        """
        if __name__ is not None:
            warnings.warn("explicit use of __name__ is deprecated", DeprecationWarning)
            resource_name = __name__
        if __opts__ is not None:
            warnings.warn("explicit use of __opts__ is deprecated, use 'opts' instead", DeprecationWarning)
            opts = __opts__
        if opts is None:
            opts = pulumi.ResourceOptions()
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.version is None:
            opts.version = utilities.get_version()
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = dict()

            __props__['admission_whitelist_patterns'] = admission_whitelist_patterns
            __props__['cluster_admission_rules'] = cluster_admission_rules
            if default_admission_rule is None:
                raise TypeError("Missing required property 'default_admission_rule'")
            __props__['default_admission_rule'] = default_admission_rule
            __props__['description'] = description
            __props__['global_policy_evaluation_mode'] = global_policy_evaluation_mode
            __props__['project'] = project
        super(Policy, __self__).__init__(
            'gcp:binaryauthorization/policy:Policy',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name, id, opts=None, admission_whitelist_patterns=None, cluster_admission_rules=None, default_admission_rule=None, description=None, global_policy_evaluation_mode=None, project=None):
        """
        Get an existing Policy resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.
        
        :param str resource_name: The unique name of the resulting resource.
        :param str id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        
        The **admission_whitelist_patterns** object supports the following:
        
          * `namePattern` (`pulumi.Input[str]`)
        
        The **cluster_admission_rules** object supports the following:
        
          * `cluster` (`pulumi.Input[str]`)
          * `enforcementMode` (`pulumi.Input[str]`)
          * `evaluationMode` (`pulumi.Input[str]`)
          * `requireAttestationsBies` (`pulumi.Input[list]`)
        
        The **default_admission_rule** object supports the following:
        
          * `enforcementMode` (`pulumi.Input[str]`)
          * `evaluationMode` (`pulumi.Input[str]`)
          * `requireAttestationsBies` (`pulumi.Input[list]`)

        > This content is derived from https://github.com/terraform-providers/terraform-provider-google/blob/master/website/docs/r/binary_authorization_policy.html.markdown.
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = dict()
        __props__["admission_whitelist_patterns"] = admission_whitelist_patterns
        __props__["cluster_admission_rules"] = cluster_admission_rules
        __props__["default_admission_rule"] = default_admission_rule
        __props__["description"] = description
        __props__["global_policy_evaluation_mode"] = global_policy_evaluation_mode
        __props__["project"] = project
        return Policy(resource_name, opts=opts, __props__=__props__)
    def translate_output_property(self, prop):
        return tables._CAMEL_TO_SNAKE_CASE_TABLE.get(prop) or prop

    def translate_input_property(self, prop):
        return tables._SNAKE_TO_CAMEL_CASE_TABLE.get(prop) or prop




# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import json
import warnings
import pulumi
import pulumi.runtime
from typing import Union
from .. import utilities, tables

class GetProjectResult:
    """
    A collection of values returned by getProject.
    """
    def __init__(__self__, app_engines=None, auto_create_network=None, billing_account=None, folder_id=None, labels=None, name=None, number=None, org_id=None, policy_data=None, policy_etag=None, project_id=None, skip_delete=None, id=None):
        if app_engines and not isinstance(app_engines, list):
            raise TypeError("Expected argument 'app_engines' to be a list")
        __self__.app_engines = app_engines
        if auto_create_network and not isinstance(auto_create_network, bool):
            raise TypeError("Expected argument 'auto_create_network' to be a bool")
        __self__.auto_create_network = auto_create_network
        if billing_account and not isinstance(billing_account, str):
            raise TypeError("Expected argument 'billing_account' to be a str")
        __self__.billing_account = billing_account
        if folder_id and not isinstance(folder_id, str):
            raise TypeError("Expected argument 'folder_id' to be a str")
        __self__.folder_id = folder_id
        if labels and not isinstance(labels, dict):
            raise TypeError("Expected argument 'labels' to be a dict")
        __self__.labels = labels
        if name and not isinstance(name, str):
            raise TypeError("Expected argument 'name' to be a str")
        __self__.name = name
        if number and not isinstance(number, str):
            raise TypeError("Expected argument 'number' to be a str")
        __self__.number = number
        if org_id and not isinstance(org_id, str):
            raise TypeError("Expected argument 'org_id' to be a str")
        __self__.org_id = org_id
        if policy_data and not isinstance(policy_data, str):
            raise TypeError("Expected argument 'policy_data' to be a str")
        __self__.policy_data = policy_data
        if policy_etag and not isinstance(policy_etag, str):
            raise TypeError("Expected argument 'policy_etag' to be a str")
        __self__.policy_etag = policy_etag
        if project_id and not isinstance(project_id, str):
            raise TypeError("Expected argument 'project_id' to be a str")
        __self__.project_id = project_id
        if skip_delete and not isinstance(skip_delete, bool):
            raise TypeError("Expected argument 'skip_delete' to be a bool")
        __self__.skip_delete = skip_delete
        if id and not isinstance(id, str):
            raise TypeError("Expected argument 'id' to be a str")
        __self__.id = id
        """
        id is the provider-assigned unique ID for this managed resource.
        """
class AwaitableGetProjectResult(GetProjectResult):
    # pylint: disable=using-constant-test
    def __await__(self):
        if False:
            yield self
        return GetProjectResult(
            app_engines=self.app_engines,
            auto_create_network=self.auto_create_network,
            billing_account=self.billing_account,
            folder_id=self.folder_id,
            labels=self.labels,
            name=self.name,
            number=self.number,
            org_id=self.org_id,
            policy_data=self.policy_data,
            policy_etag=self.policy_etag,
            project_id=self.project_id,
            skip_delete=self.skip_delete,
            id=self.id)

def get_project(project_id=None,opts=None):
    """
    Use this data source to get project details.
    For more information see 
    [API](https://cloud.google.com/resource-manager/reference/rest/v1/projects#Project)
    
    :param str project_id: The project ID. If it is not provided, the provider project is used.

    > This content is derived from https://github.com/terraform-providers/terraform-provider-google/blob/master/website/docs/d/project.html.markdown.
    """
    __args__ = dict()

    __args__['projectId'] = project_id
    if opts is None:
        opts = pulumi.InvokeOptions()
    if opts.version is None:
        opts.version = utilities.get_version()
    __ret__ = pulumi.runtime.invoke('gcp:organizations/getProject:getProject', __args__, opts=opts).value

    return AwaitableGetProjectResult(
        app_engines=__ret__.get('appEngines'),
        auto_create_network=__ret__.get('autoCreateNetwork'),
        billing_account=__ret__.get('billingAccount'),
        folder_id=__ret__.get('folderId'),
        labels=__ret__.get('labels'),
        name=__ret__.get('name'),
        number=__ret__.get('number'),
        org_id=__ret__.get('orgId'),
        policy_data=__ret__.get('policyData'),
        policy_etag=__ret__.get('policyEtag'),
        project_id=__ret__.get('projectId'),
        skip_delete=__ret__.get('skipDelete'),
        id=__ret__.get('id'))



# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import json
import warnings
import pulumi
import pulumi.runtime
from typing import Union
from .. import utilities, tables

class IAMPolicy(pulumi.CustomResource):
    etag: pulumi.Output[str]
    """
    (Computed) The etag of the service account IAM policy.
    """
    policy_data: pulumi.Output[str]
    """
    The policy data generated by
    a `organizations.getIAMPolicy` data source.
    """
    service_account_id: pulumi.Output[str]
    """
    The fully-qualified name of the service account to apply policy to.
    """
    def __init__(__self__, resource_name, opts=None, policy_data=None, service_account_id=None, __props__=None, __name__=None, __opts__=None):
        """
        When managing IAM roles, you can treat a service account either as a resource or as an identity. This resource is to add iam policy bindings to a service account resource **to configure permissions for who can edit the service account**. To configure permissions for a service account to act as an identity that can manage other GCP resources, use the google_project_iam set of resources.
        
        Three different resources help you manage your IAM policy for a service account. Each of these resources serves a different use case:
        
        * `serviceAccount.IAMPolicy`: Authoritative. Sets the IAM policy for the service account and replaces any existing policy already attached.
        * `serviceAccount.IAMBinding`: Authoritative for a given role. Updates the IAM policy to grant a role to a list of members. Other roles within the IAM policy for the service account are preserved.
        * `serviceAccount.IAMMember`: Non-authoritative. Updates the IAM policy to grant a role to a new member. Other members for the role for the service account are preserved.
        
        > **Note:** `serviceAccount.IAMPolicy` **cannot** be used in conjunction with `serviceAccount.IAMBinding` and `serviceAccount.IAMMember` or they will fight over what your policy should be.
        
        > **Note:** `serviceAccount.IAMBinding` resources **can be** used in conjunction with `serviceAccount.IAMMember` resources **only if** they do not grant privilege to the same role.
        
        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[str] policy_data: The policy data generated by
               a `organizations.getIAMPolicy` data source.
        :param pulumi.Input[str] service_account_id: The fully-qualified name of the service account to apply policy to.

        > This content is derived from https://github.com/terraform-providers/terraform-provider-google/blob/master/website/docs/r/service_account_iam_policy.html.markdown.
        """
        if __name__ is not None:
            warnings.warn("explicit use of __name__ is deprecated", DeprecationWarning)
            resource_name = __name__
        if __opts__ is not None:
            warnings.warn("explicit use of __opts__ is deprecated, use 'opts' instead", DeprecationWarning)
            opts = __opts__
        if opts is None:
            opts = pulumi.ResourceOptions()
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.version is None:
            opts.version = utilities.get_version()
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = dict()

            if policy_data is None:
                raise TypeError("Missing required property 'policy_data'")
            __props__['policy_data'] = policy_data
            if service_account_id is None:
                raise TypeError("Missing required property 'service_account_id'")
            __props__['service_account_id'] = service_account_id
            __props__['etag'] = None
        super(IAMPolicy, __self__).__init__(
            'gcp:serviceAccount/iAMPolicy:IAMPolicy',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name, id, opts=None, etag=None, policy_data=None, service_account_id=None):
        """
        Get an existing IAMPolicy resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.
        
        :param str resource_name: The unique name of the resulting resource.
        :param str id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[str] etag: (Computed) The etag of the service account IAM policy.
        :param pulumi.Input[str] policy_data: The policy data generated by
               a `organizations.getIAMPolicy` data source.
        :param pulumi.Input[str] service_account_id: The fully-qualified name of the service account to apply policy to.

        > This content is derived from https://github.com/terraform-providers/terraform-provider-google/blob/master/website/docs/r/service_account_iam_policy.html.markdown.
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = dict()
        __props__["etag"] = etag
        __props__["policy_data"] = policy_data
        __props__["service_account_id"] = service_account_id
        return IAMPolicy(resource_name, opts=opts, __props__=__props__)
    def translate_output_property(self, prop):
        return tables._CAMEL_TO_SNAKE_CASE_TABLE.get(prop) or prop

    def translate_input_property(self, prop):
        return tables._SNAKE_TO_CAMEL_CASE_TABLE.get(prop) or prop




# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import json
import warnings
import pulumi
import pulumi.runtime
from typing import Union
from .. import utilities, tables

class GetSSLPolicyResult:
    """
    A collection of values returned by getSSLPolicy.
    """
    def __init__(__self__, creation_timestamp=None, custom_features=None, description=None, enabled_features=None, fingerprint=None, min_tls_version=None, name=None, profile=None, project=None, self_link=None, id=None):
        if creation_timestamp and not isinstance(creation_timestamp, str):
            raise TypeError("Expected argument 'creation_timestamp' to be a str")
        __self__.creation_timestamp = creation_timestamp
        if custom_features and not isinstance(custom_features, list):
            raise TypeError("Expected argument 'custom_features' to be a list")
        __self__.custom_features = custom_features
        """
        If the `profile` is `CUSTOM`, these are the custom encryption
        ciphers supported by the profile. If the `profile` is *not* `CUSTOM`, this
        attribute will be empty.
        """
        if description and not isinstance(description, str):
            raise TypeError("Expected argument 'description' to be a str")
        __self__.description = description
        """
        Description of this SSL Policy.
        """
        if enabled_features and not isinstance(enabled_features, list):
            raise TypeError("Expected argument 'enabled_features' to be a list")
        __self__.enabled_features = enabled_features
        """
        The set of enabled encryption ciphers as a result of the policy config
        """
        if fingerprint and not isinstance(fingerprint, str):
            raise TypeError("Expected argument 'fingerprint' to be a str")
        __self__.fingerprint = fingerprint
        """
        Fingerprint of this resource.
        """
        if min_tls_version and not isinstance(min_tls_version, str):
            raise TypeError("Expected argument 'min_tls_version' to be a str")
        __self__.min_tls_version = min_tls_version
        """
        The minimum supported TLS version of this policy.
        """
        if name and not isinstance(name, str):
            raise TypeError("Expected argument 'name' to be a str")
        __self__.name = name
        if profile and not isinstance(profile, str):
            raise TypeError("Expected argument 'profile' to be a str")
        __self__.profile = profile
        """
        The Google-curated or custom profile used by this policy.
        """
        if project and not isinstance(project, str):
            raise TypeError("Expected argument 'project' to be a str")
        __self__.project = project
        if self_link and not isinstance(self_link, str):
            raise TypeError("Expected argument 'self_link' to be a str")
        __self__.self_link = self_link
        """
        The URI of the created resource.
        """
        if id and not isinstance(id, str):
            raise TypeError("Expected argument 'id' to be a str")
        __self__.id = id
        """
        id is the provider-assigned unique ID for this managed resource.
        """
class AwaitableGetSSLPolicyResult(GetSSLPolicyResult):
    # pylint: disable=using-constant-test
    def __await__(self):
        if False:
            yield self
        return GetSSLPolicyResult(
            creation_timestamp=self.creation_timestamp,
            custom_features=self.custom_features,
            description=self.description,
            enabled_features=self.enabled_features,
            fingerprint=self.fingerprint,
            min_tls_version=self.min_tls_version,
            name=self.name,
            profile=self.profile,
            project=self.project,
            self_link=self.self_link,
            id=self.id)

def get_ssl_policy(name=None,project=None,opts=None):
    """
    Gets an SSL Policy within GCE from its name, for use with Target HTTPS and Target SSL Proxies.
        For more information see [the official documentation](https://cloud.google.com/compute/docs/load-balancing/ssl-policies).
    
    :param str name: The name of the SSL Policy.
    :param str project: The ID of the project in which the resource belongs. If it
           is not provided, the provider project is used.

    > This content is derived from https://github.com/terraform-providers/terraform-provider-google/blob/master/website/docs/d/compute_ssl_policy.html.markdown.
    """
    __args__ = dict()

    __args__['name'] = name
    __args__['project'] = project
    if opts is None:
        opts = pulumi.InvokeOptions()
    if opts.version is None:
        opts.version = utilities.get_version()
    __ret__ = pulumi.runtime.invoke('gcp:compute/getSSLPolicy:getSSLPolicy', __args__, opts=opts).value

    return AwaitableGetSSLPolicyResult(
        creation_timestamp=__ret__.get('creationTimestamp'),
        custom_features=__ret__.get('customFeatures'),
        description=__ret__.get('description'),
        enabled_features=__ret__.get('enabledFeatures'),
        fingerprint=__ret__.get('fingerprint'),
        min_tls_version=__ret__.get('minTlsVersion'),
        name=__ret__.get('name'),
        profile=__ret__.get('profile'),
        project=__ret__.get('project'),
        self_link=__ret__.get('selfLink'),
        id=__ret__.get('id'))



# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import json
import warnings
import pulumi
import pulumi.runtime
from typing import Union
from .. import utilities, tables

class Metric(pulumi.CustomResource):
    bucket_options: pulumi.Output[dict]
    description: pulumi.Output[str]
    filter: pulumi.Output[str]
    label_extractors: pulumi.Output[dict]
    metric_descriptor: pulumi.Output[dict]
    name: pulumi.Output[str]
    project: pulumi.Output[str]
    value_extractor: pulumi.Output[str]
    def __init__(__self__, resource_name, opts=None, bucket_options=None, description=None, filter=None, label_extractors=None, metric_descriptor=None, name=None, project=None, value_extractor=None, __props__=None, __name__=None, __opts__=None):
        """
        Create a Metric resource with the given unique name, props, and options.
        
        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        
        The **bucket_options** object supports the following:
        
          * `explicitBuckets` (`pulumi.Input[dict]`)
        
            * `bounds` (`pulumi.Input[list]`)
        
          * `exponentialBuckets` (`pulumi.Input[dict]`)
        
            * `growthFactor` (`pulumi.Input[float]`)
            * `numFiniteBuckets` (`pulumi.Input[float]`)
            * `scale` (`pulumi.Input[float]`)
        
          * `linearBuckets` (`pulumi.Input[dict]`)
        
            * `numFiniteBuckets` (`pulumi.Input[float]`)
            * `offset` (`pulumi.Input[float]`)
            * `width` (`pulumi.Input[float]`)
        
        The **metric_descriptor** object supports the following:
        
          * `labels` (`pulumi.Input[list]`)
        
            * `description` (`pulumi.Input[str]`)
            * `key` (`pulumi.Input[str]`)
            * `valueType` (`pulumi.Input[str]`)
        
          * `metricKind` (`pulumi.Input[str]`)
          * `unit` (`pulumi.Input[str]`)
          * `valueType` (`pulumi.Input[str]`)

        > This content is derived from https://github.com/terraform-providers/terraform-provider-google/blob/master/website/docs/r/logging_metric.html.markdown.
        """
        if __name__ is not None:
            warnings.warn("explicit use of __name__ is deprecated", DeprecationWarning)
            resource_name = __name__
        if __opts__ is not None:
            warnings.warn("explicit use of __opts__ is deprecated, use 'opts' instead", DeprecationWarning)
            opts = __opts__
        if opts is None:
            opts = pulumi.ResourceOptions()
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.version is None:
            opts.version = utilities.get_version()
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = dict()

            __props__['bucket_options'] = bucket_options
            __props__['description'] = description
            if filter is None:
                raise TypeError("Missing required property 'filter'")
            __props__['filter'] = filter
            __props__['label_extractors'] = label_extractors
            if metric_descriptor is None:
                raise TypeError("Missing required property 'metric_descriptor'")
            __props__['metric_descriptor'] = metric_descriptor
            __props__['name'] = name
            __props__['project'] = project
            __props__['value_extractor'] = value_extractor
        super(Metric, __self__).__init__(
            'gcp:logging/metric:Metric',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name, id, opts=None, bucket_options=None, description=None, filter=None, label_extractors=None, metric_descriptor=None, name=None, project=None, value_extractor=None):
        """
        Get an existing Metric resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.
        
        :param str resource_name: The unique name of the resulting resource.
        :param str id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        
        The **bucket_options** object supports the following:
        
          * `explicitBuckets` (`pulumi.Input[dict]`)
        
            * `bounds` (`pulumi.Input[list]`)
        
          * `exponentialBuckets` (`pulumi.Input[dict]`)
        
            * `growthFactor` (`pulumi.Input[float]`)
            * `numFiniteBuckets` (`pulumi.Input[float]`)
            * `scale` (`pulumi.Input[float]`)
        
          * `linearBuckets` (`pulumi.Input[dict]`)
        
            * `numFiniteBuckets` (`pulumi.Input[float]`)
            * `offset` (`pulumi.Input[float]`)
            * `width` (`pulumi.Input[float]`)
        
        The **metric_descriptor** object supports the following:
        
          * `labels` (`pulumi.Input[list]`)
        
            * `description` (`pulumi.Input[str]`)
            * `key` (`pulumi.Input[str]`)
            * `valueType` (`pulumi.Input[str]`)
        
          * `metricKind` (`pulumi.Input[str]`)
          * `unit` (`pulumi.Input[str]`)
          * `valueType` (`pulumi.Input[str]`)

        > This content is derived from https://github.com/terraform-providers/terraform-provider-google/blob/master/website/docs/r/logging_metric.html.markdown.
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = dict()
        __props__["bucket_options"] = bucket_options
        __props__["description"] = description
        __props__["filter"] = filter
        __props__["label_extractors"] = label_extractors
        __props__["metric_descriptor"] = metric_descriptor
        __props__["name"] = name
        __props__["project"] = project
        __props__["value_extractor"] = value_extractor
        return Metric(resource_name, opts=opts, __props__=__props__)
    def translate_output_property(self, prop):
        return tables._CAMEL_TO_SNAKE_CASE_TABLE.get(prop) or prop

    def translate_input_property(self, prop):
        return tables._SNAKE_TO_CAMEL_CASE_TABLE.get(prop) or prop




# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import json
import warnings
import pulumi
import pulumi.runtime
from typing import Union
from .. import utilities, tables

class Lien(pulumi.CustomResource):
    create_time: pulumi.Output[str]
    name: pulumi.Output[str]
    origin: pulumi.Output[str]
    parent: pulumi.Output[str]
    reason: pulumi.Output[str]
    restrictions: pulumi.Output[list]
    def __init__(__self__, resource_name, opts=None, origin=None, parent=None, reason=None, restrictions=None, __props__=None, __name__=None, __opts__=None):
        """
        A Lien represents an encumbrance on the actions that can be performed on a resource.
        
        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.

        > This content is derived from https://github.com/terraform-providers/terraform-provider-google/blob/master/website/docs/r/resource_manager_lien.html.markdown.
        """
        if __name__ is not None:
            warnings.warn("explicit use of __name__ is deprecated", DeprecationWarning)
            resource_name = __name__
        if __opts__ is not None:
            warnings.warn("explicit use of __opts__ is deprecated, use 'opts' instead", DeprecationWarning)
            opts = __opts__
        if opts is None:
            opts = pulumi.ResourceOptions()
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.version is None:
            opts.version = utilities.get_version()
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = dict()

            if origin is None:
                raise TypeError("Missing required property 'origin'")
            __props__['origin'] = origin
            if parent is None:
                raise TypeError("Missing required property 'parent'")
            __props__['parent'] = parent
            if reason is None:
                raise TypeError("Missing required property 'reason'")
            __props__['reason'] = reason
            if restrictions is None:
                raise TypeError("Missing required property 'restrictions'")
            __props__['restrictions'] = restrictions
            __props__['create_time'] = None
            __props__['name'] = None
        super(Lien, __self__).__init__(
            'gcp:resourcemanager/lien:Lien',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name, id, opts=None, create_time=None, name=None, origin=None, parent=None, reason=None, restrictions=None):
        """
        Get an existing Lien resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.
        
        :param str resource_name: The unique name of the resulting resource.
        :param str id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.

        > This content is derived from https://github.com/terraform-providers/terraform-provider-google/blob/master/website/docs/r/resource_manager_lien.html.markdown.
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = dict()
        __props__["create_time"] = create_time
        __props__["name"] = name
        __props__["origin"] = origin
        __props__["parent"] = parent
        __props__["reason"] = reason
        __props__["restrictions"] = restrictions
        return Lien(resource_name, opts=opts, __props__=__props__)
    def translate_output_property(self, prop):
        return tables._CAMEL_TO_SNAKE_CASE_TABLE.get(prop) or prop

    def translate_input_property(self, prop):
        return tables._SNAKE_TO_CAMEL_CASE_TABLE.get(prop) or prop




# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import json
import warnings
import pulumi
import pulumi.runtime
from typing import Union
from .. import utilities, tables

class InstanceTemplate(pulumi.CustomResource):
    can_ip_forward: pulumi.Output[bool]
    """
    Whether to allow sending and receiving of
    packets with non-matching source or destination IPs. This defaults to false.
    """
    description: pulumi.Output[str]
    """
    A brief description of this resource.
    """
    disks: pulumi.Output[list]
    """
    Disks to attach to instances created from this template.
    This can be specified multiple times for multiple disks. Structure is
    documented below.
    
      * `autoDelete` (`bool`)
      * `boot` (`bool`)
      * `device_name` (`str`)
      * `disk_encryption_key` (`dict`)
    
        * `kmsKeySelfLink` (`str`)
    
      * `diskName` (`str`)
      * `disk_size_gb` (`float`)
      * `diskType` (`str`)
      * `interface` (`str`)
      * `labels` (`dict`) - A set of key/value label pairs to assign to instances
        created from this template,
      * `mode` (`str`)
      * `source` (`str`)
      * `sourceImage` (`str`)
      * `type` (`str`)
    """
    guest_accelerators: pulumi.Output[list]
    """
    List of the type and count of accelerator cards attached to the instance. Structure documented below.
    
      * `count` (`float`)
      * `type` (`str`)
    """
    instance_description: pulumi.Output[str]
    """
    A brief description to use for instances
    created from this template.
    """
    labels: pulumi.Output[dict]
    """
    A set of key/value label pairs to assign to instances
    created from this template,
    """
    machine_type: pulumi.Output[str]
    """
    The machine type to create.
    """
    metadata: pulumi.Output[dict]
    """
    Metadata key/value pairs to make available from
    within instances created from this template.
    """
    metadata_fingerprint: pulumi.Output[str]
    """
    The unique fingerprint of the metadata.
    """
    metadata_startup_script: pulumi.Output[str]
    """
    An alternative to using the
    startup-script metadata key, mostly to match the compute_instance resource.
    This replaces the startup-script metadata key on the created instance and
    thus the two mechanisms are not allowed to be used simultaneously.
    """
    min_cpu_platform: pulumi.Output[str]
    """
    Specifies a minimum CPU platform. Applicable values are the friendly names of CPU platforms, such as
    `Intel Haswell` or `Intel Skylake`. See the complete list [here](https://cloud.google.com/compute/docs/instances/specify-min-cpu-platform).
    """
    name: pulumi.Output[str]
    """
    The name of the instance template. If you leave
    this blank, this provider will auto-generate a unique name.
    """
    name_prefix: pulumi.Output[str]
    """
    Creates a unique name beginning with the specified
    prefix. Conflicts with `name`.
    """
    network_interfaces: pulumi.Output[list]
    """
    Networks to attach to instances created from
    this template. This can be specified multiple times for multiple networks.
    Structure is documented below.
    
      * `accessConfigs` (`list`)
    
        * `natIp` (`str`)
        * `network_tier` (`str`)
    
      * `aliasIpRanges` (`list`)
    
        * `ip_cidr_range` (`str`)
        * `subnetworkRangeName` (`str`)
    
      * `network` (`str`)
      * `networkIp` (`str`)
      * `subnetwork` (`str`)
      * `subnetworkProject` (`str`)
    """
    project: pulumi.Output[str]
    """
    The ID of the project in which the resource belongs. If it
    is not provided, the provider project is used.
    """
    region: pulumi.Output[str]
    """
    An instance template is a global resource that is not
    bound to a zone or a region. However, you can still specify some regional
    resources in an instance template, which restricts the template to the
    region where that resource resides. For example, a custom `subnetwork`
    resource is tied to a specific region. Defaults to the region of the
    Provider if no value is given.
    """
    scheduling: pulumi.Output[dict]
    """
    The scheduling strategy to use. More details about
    this configuration option are detailed below.
    
      * `automaticRestart` (`bool`)
      * `nodeAffinities` (`list`)
    
        * `key` (`str`)
        * `operator` (`str`)
        * `values` (`list`)
    
      * `onHostMaintenance` (`str`)
      * `preemptible` (`bool`)
    """
    self_link: pulumi.Output[str]
    """
    The URI of the created resource.
    """
    service_account: pulumi.Output[dict]
    """
    Service account to attach to the instance. Structure is documented below.
    
      * `email` (`str`)
      * `scopes` (`list`)
    """
    shielded_instance_config: pulumi.Output[dict]
    """
    Enable [Shielded VM](https://cloud.google.com/security/shielded-cloud/shielded-vm) on this instance. Shielded VM provides verifiable integrity to prevent against malware and rootkits. Defaults to disabled. Structure is documented below.
    **Note**: `shielded_instance_config` can only be used with boot images with shielded vm support. See the complete list [here](https://cloud.google.com/compute/docs/images#shielded-images).
    
      * `enableIntegrityMonitoring` (`bool`)
      * `enableSecureBoot` (`bool`)
      * `enableVtpm` (`bool`)
    """
    tags: pulumi.Output[list]
    """
    Tags to attach to the instance.
    """
    tags_fingerprint: pulumi.Output[str]
    """
    The unique fingerprint of the tags.
    """
    def __init__(__self__, resource_name, opts=None, can_ip_forward=None, description=None, disks=None, guest_accelerators=None, instance_description=None, labels=None, machine_type=None, metadata=None, metadata_startup_script=None, min_cpu_platform=None, name=None, name_prefix=None, network_interfaces=None, project=None, region=None, scheduling=None, service_account=None, shielded_instance_config=None, tags=None, __props__=None, __name__=None, __opts__=None):
        """
        Manages a VM instance template resource within GCE. For more information see
        [the official documentation](https://cloud.google.com/compute/docs/instance-templates)
        and
        [API](https://cloud.google.com/compute/docs/reference/latest/instanceTemplates).
        
        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[bool] can_ip_forward: Whether to allow sending and receiving of
               packets with non-matching source or destination IPs. This defaults to false.
        :param pulumi.Input[str] description: A brief description of this resource.
        :param pulumi.Input[list] disks: Disks to attach to instances created from this template.
               This can be specified multiple times for multiple disks. Structure is
               documented below.
        :param pulumi.Input[list] guest_accelerators: List of the type and count of accelerator cards attached to the instance. Structure documented below.
        :param pulumi.Input[str] instance_description: A brief description to use for instances
               created from this template.
        :param pulumi.Input[dict] labels: A set of key/value label pairs to assign to instances
               created from this template,
        :param pulumi.Input[str] machine_type: The machine type to create.
        :param pulumi.Input[dict] metadata: Metadata key/value pairs to make available from
               within instances created from this template.
        :param pulumi.Input[str] metadata_startup_script: An alternative to using the
               startup-script metadata key, mostly to match the compute_instance resource.
               This replaces the startup-script metadata key on the created instance and
               thus the two mechanisms are not allowed to be used simultaneously.
        :param pulumi.Input[str] min_cpu_platform: Specifies a minimum CPU platform. Applicable values are the friendly names of CPU platforms, such as
               `Intel Haswell` or `Intel Skylake`. See the complete list [here](https://cloud.google.com/compute/docs/instances/specify-min-cpu-platform).
        :param pulumi.Input[str] name: The name of the instance template. If you leave
               this blank, this provider will auto-generate a unique name.
        :param pulumi.Input[str] name_prefix: Creates a unique name beginning with the specified
               prefix. Conflicts with `name`.
        :param pulumi.Input[list] network_interfaces: Networks to attach to instances created from
               this template. This can be specified multiple times for multiple networks.
               Structure is documented below.
        :param pulumi.Input[str] project: The ID of the project in which the resource belongs. If it
               is not provided, the provider project is used.
        :param pulumi.Input[str] region: An instance template is a global resource that is not
               bound to a zone or a region. However, you can still specify some regional
               resources in an instance template, which restricts the template to the
               region where that resource resides. For example, a custom `subnetwork`
               resource is tied to a specific region. Defaults to the region of the
               Provider if no value is given.
        :param pulumi.Input[dict] scheduling: The scheduling strategy to use. More details about
               this configuration option are detailed below.
        :param pulumi.Input[dict] service_account: Service account to attach to the instance. Structure is documented below.
        :param pulumi.Input[dict] shielded_instance_config: Enable [Shielded VM](https://cloud.google.com/security/shielded-cloud/shielded-vm) on this instance. Shielded VM provides verifiable integrity to prevent against malware and rootkits. Defaults to disabled. Structure is documented below.
               **Note**: `shielded_instance_config` can only be used with boot images with shielded vm support. See the complete list [here](https://cloud.google.com/compute/docs/images#shielded-images).
        :param pulumi.Input[list] tags: Tags to attach to the instance.
        
        The **disks** object supports the following:
        
          * `autoDelete` (`pulumi.Input[bool]`)
          * `boot` (`pulumi.Input[bool]`)
          * `device_name` (`pulumi.Input[str]`)
          * `disk_encryption_key` (`pulumi.Input[dict]`)
        
            * `kmsKeySelfLink` (`pulumi.Input[str]`)
        
          * `diskName` (`pulumi.Input[str]`)
          * `disk_size_gb` (`pulumi.Input[float]`)
          * `diskType` (`pulumi.Input[str]`)
          * `interface` (`pulumi.Input[str]`)
          * `labels` (`pulumi.Input[dict]`) - A set of key/value label pairs to assign to instances
            created from this template,
          * `mode` (`pulumi.Input[str]`)
          * `source` (`pulumi.Input[str]`)
          * `sourceImage` (`pulumi.Input[str]`)
          * `type` (`pulumi.Input[str]`)
        
        The **guest_accelerators** object supports the following:
        
          * `count` (`pulumi.Input[float]`)
          * `type` (`pulumi.Input[str]`)
        
        The **network_interfaces** object supports the following:
        
          * `accessConfigs` (`pulumi.Input[list]`)
        
            * `natIp` (`pulumi.Input[str]`)
            * `network_tier` (`pulumi.Input[str]`)
        
          * `aliasIpRanges` (`pulumi.Input[list]`)
        
            * `ip_cidr_range` (`pulumi.Input[str]`)
            * `subnetworkRangeName` (`pulumi.Input[str]`)
        
          * `network` (`pulumi.Input[str]`)
          * `networkIp` (`pulumi.Input[str]`)
          * `subnetwork` (`pulumi.Input[str]`)
          * `subnetworkProject` (`pulumi.Input[str]`)
        
        The **scheduling** object supports the following:
        
          * `automaticRestart` (`pulumi.Input[bool]`)
          * `nodeAffinities` (`pulumi.Input[list]`)
        
            * `key` (`pulumi.Input[str]`)
            * `operator` (`pulumi.Input[str]`)
            * `values` (`pulumi.Input[list]`)
        
          * `onHostMaintenance` (`pulumi.Input[str]`)
          * `preemptible` (`pulumi.Input[bool]`)
        
        The **service_account** object supports the following:
        
          * `email` (`pulumi.Input[str]`)
          * `scopes` (`pulumi.Input[list]`)
        
        The **shielded_instance_config** object supports the following:
        
          * `enableIntegrityMonitoring` (`pulumi.Input[bool]`)
          * `enableSecureBoot` (`pulumi.Input[bool]`)
          * `enableVtpm` (`pulumi.Input[bool]`)

        > This content is derived from https://github.com/terraform-providers/terraform-provider-google/blob/master/website/docs/r/compute_instance_template.html.markdown.
        """
        if __name__ is not None:
            warnings.warn("explicit use of __name__ is deprecated", DeprecationWarning)
            resource_name = __name__
        if __opts__ is not None:
            warnings.warn("explicit use of __opts__ is deprecated, use 'opts' instead", DeprecationWarning)
            opts = __opts__
        if opts is None:
            opts = pulumi.ResourceOptions()
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.version is None:
            opts.version = utilities.get_version()
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = dict()

            __props__['can_ip_forward'] = can_ip_forward
            __props__['description'] = description
            if disks is None:
                raise TypeError("Missing required property 'disks'")
            __props__['disks'] = disks
            __props__['guest_accelerators'] = guest_accelerators
            __props__['instance_description'] = instance_description
            __props__['labels'] = labels
            if machine_type is None:
                raise TypeError("Missing required property 'machine_type'")
            __props__['machine_type'] = machine_type
            __props__['metadata'] = metadata
            __props__['metadata_startup_script'] = metadata_startup_script
            __props__['min_cpu_platform'] = min_cpu_platform
            __props__['name'] = name
            __props__['name_prefix'] = name_prefix
            __props__['network_interfaces'] = network_interfaces
            __props__['project'] = project
            __props__['region'] = region
            __props__['scheduling'] = scheduling
            __props__['service_account'] = service_account
            __props__['shielded_instance_config'] = shielded_instance_config
            __props__['tags'] = tags
            __props__['metadata_fingerprint'] = None
            __props__['self_link'] = None
            __props__['tags_fingerprint'] = None
        super(InstanceTemplate, __self__).__init__(
            'gcp:compute/instanceTemplate:InstanceTemplate',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name, id, opts=None, can_ip_forward=None, description=None, disks=None, guest_accelerators=None, instance_description=None, labels=None, machine_type=None, metadata=None, metadata_fingerprint=None, metadata_startup_script=None, min_cpu_platform=None, name=None, name_prefix=None, network_interfaces=None, project=None, region=None, scheduling=None, self_link=None, service_account=None, shielded_instance_config=None, tags=None, tags_fingerprint=None):
        """
        Get an existing InstanceTemplate resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.
        
        :param str resource_name: The unique name of the resulting resource.
        :param str id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[bool] can_ip_forward: Whether to allow sending and receiving of
               packets with non-matching source or destination IPs. This defaults to false.
        :param pulumi.Input[str] description: A brief description of this resource.
        :param pulumi.Input[list] disks: Disks to attach to instances created from this template.
               This can be specified multiple times for multiple disks. Structure is
               documented below.
        :param pulumi.Input[list] guest_accelerators: List of the type and count of accelerator cards attached to the instance. Structure documented below.
        :param pulumi.Input[str] instance_description: A brief description to use for instances
               created from this template.
        :param pulumi.Input[dict] labels: A set of key/value label pairs to assign to instances
               created from this template,
        :param pulumi.Input[str] machine_type: The machine type to create.
        :param pulumi.Input[dict] metadata: Metadata key/value pairs to make available from
               within instances created from this template.
        :param pulumi.Input[str] metadata_fingerprint: The unique fingerprint of the metadata.
        :param pulumi.Input[str] metadata_startup_script: An alternative to using the
               startup-script metadata key, mostly to match the compute_instance resource.
               This replaces the startup-script metadata key on the created instance and
               thus the two mechanisms are not allowed to be used simultaneously.
        :param pulumi.Input[str] min_cpu_platform: Specifies a minimum CPU platform. Applicable values are the friendly names of CPU platforms, such as
               `Intel Haswell` or `Intel Skylake`. See the complete list [here](https://cloud.google.com/compute/docs/instances/specify-min-cpu-platform).
        :param pulumi.Input[str] name: The name of the instance template. If you leave
               this blank, this provider will auto-generate a unique name.
        :param pulumi.Input[str] name_prefix: Creates a unique name beginning with the specified
               prefix. Conflicts with `name`.
        :param pulumi.Input[list] network_interfaces: Networks to attach to instances created from
               this template. This can be specified multiple times for multiple networks.
               Structure is documented below.
        :param pulumi.Input[str] project: The ID of the project in which the resource belongs. If it
               is not provided, the provider project is used.
        :param pulumi.Input[str] region: An instance template is a global resource that is not
               bound to a zone or a region. However, you can still specify some regional
               resources in an instance template, which restricts the template to the
               region where that resource resides. For example, a custom `subnetwork`
               resource is tied to a specific region. Defaults to the region of the
               Provider if no value is given.
        :param pulumi.Input[dict] scheduling: The scheduling strategy to use. More details about
               this configuration option are detailed below.
        :param pulumi.Input[str] self_link: The URI of the created resource.
        :param pulumi.Input[dict] service_account: Service account to attach to the instance. Structure is documented below.
        :param pulumi.Input[dict] shielded_instance_config: Enable [Shielded VM](https://cloud.google.com/security/shielded-cloud/shielded-vm) on this instance. Shielded VM provides verifiable integrity to prevent against malware and rootkits. Defaults to disabled. Structure is documented below.
               **Note**: `shielded_instance_config` can only be used with boot images with shielded vm support. See the complete list [here](https://cloud.google.com/compute/docs/images#shielded-images).
        :param pulumi.Input[list] tags: Tags to attach to the instance.
        :param pulumi.Input[str] tags_fingerprint: The unique fingerprint of the tags.
        
        The **disks** object supports the following:
        
          * `autoDelete` (`pulumi.Input[bool]`)
          * `boot` (`pulumi.Input[bool]`)
          * `device_name` (`pulumi.Input[str]`)
          * `disk_encryption_key` (`pulumi.Input[dict]`)
        
            * `kmsKeySelfLink` (`pulumi.Input[str]`)
        
          * `diskName` (`pulumi.Input[str]`)
          * `disk_size_gb` (`pulumi.Input[float]`)
          * `diskType` (`pulumi.Input[str]`)
          * `interface` (`pulumi.Input[str]`)
          * `labels` (`pulumi.Input[dict]`) - A set of key/value label pairs to assign to instances
            created from this template,
          * `mode` (`pulumi.Input[str]`)
          * `source` (`pulumi.Input[str]`)
          * `sourceImage` (`pulumi.Input[str]`)
          * `type` (`pulumi.Input[str]`)
        
        The **guest_accelerators** object supports the following:
        
          * `count` (`pulumi.Input[float]`)
          * `type` (`pulumi.Input[str]`)
        
        The **network_interfaces** object supports the following:
        
          * `accessConfigs` (`pulumi.Input[list]`)
        
            * `natIp` (`pulumi.Input[str]`)
            * `network_tier` (`pulumi.Input[str]`)
        
          * `aliasIpRanges` (`pulumi.Input[list]`)
        
            * `ip_cidr_range` (`pulumi.Input[str]`)
            * `subnetworkRangeName` (`pulumi.Input[str]`)
        
          * `network` (`pulumi.Input[str]`)
          * `networkIp` (`pulumi.Input[str]`)
          * `subnetwork` (`pulumi.Input[str]`)
          * `subnetworkProject` (`pulumi.Input[str]`)
        
        The **scheduling** object supports the following:
        
          * `automaticRestart` (`pulumi.Input[bool]`)
          * `nodeAffinities` (`pulumi.Input[list]`)
        
            * `key` (`pulumi.Input[str]`)
            * `operator` (`pulumi.Input[str]`)
            * `values` (`pulumi.Input[list]`)
        
          * `onHostMaintenance` (`pulumi.Input[str]`)
          * `preemptible` (`pulumi.Input[bool]`)
        
        The **service_account** object supports the following:
        
          * `email` (`pulumi.Input[str]`)
          * `scopes` (`pulumi.Input[list]`)
        
        The **shielded_instance_config** object supports the following:
        
          * `enableIntegrityMonitoring` (`pulumi.Input[bool]`)
          * `enableSecureBoot` (`pulumi.Input[bool]`)
          * `enableVtpm` (`pulumi.Input[bool]`)

        > This content is derived from https://github.com/terraform-providers/terraform-provider-google/blob/master/website/docs/r/compute_instance_template.html.markdown.
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = dict()
        __props__["can_ip_forward"] = can_ip_forward
        __props__["description"] = description
        __props__["disks"] = disks
        __props__["guest_accelerators"] = guest_accelerators
        __props__["instance_description"] = instance_description
        __props__["labels"] = labels
        __props__["machine_type"] = machine_type
        __props__["metadata"] = metadata
        __props__["metadata_fingerprint"] = metadata_fingerprint
        __props__["metadata_startup_script"] = metadata_startup_script
        __props__["min_cpu_platform"] = min_cpu_platform
        __props__["name"] = name
        __props__["name_prefix"] = name_prefix
        __props__["network_interfaces"] = network_interfaces
        __props__["project"] = project
        __props__["region"] = region
        __props__["scheduling"] = scheduling
        __props__["self_link"] = self_link
        __props__["service_account"] = service_account
        __props__["shielded_instance_config"] = shielded_instance_config
        __props__["tags"] = tags
        __props__["tags_fingerprint"] = tags_fingerprint
        return InstanceTemplate(resource_name, opts=opts, __props__=__props__)
    def translate_output_property(self, prop):
        return tables._CAMEL_TO_SNAKE_CASE_TABLE.get(prop) or prop

    def translate_input_property(self, prop):
        return tables._SNAKE_TO_CAMEL_CASE_TABLE.get(prop) or prop




# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import json
import warnings
import pulumi
import pulumi.runtime
from typing import Union
from .. import utilities, tables

class IAMCustomRole(pulumi.CustomResource):
    deleted: pulumi.Output[bool]
    """
    (Optional) The current deleted state of the role.
    """
    description: pulumi.Output[str]
    """
    A human-readable description for the role.
    """
    org_id: pulumi.Output[str]
    """
    The numeric ID of the organization in which you want to create a custom role.
    """
    permissions: pulumi.Output[list]
    """
    The names of the permissions this role grants when bound in an IAM policy. At least one permission must be specified.
    """
    role_id: pulumi.Output[str]
    """
    The role id to use for this role.
    """
    stage: pulumi.Output[str]
    """
    The current launch stage of the role.
    Defaults to `GA`.
    List of possible stages is [here](https://cloud.google.com/iam/reference/rest/v1/organizations.roles#Role.RoleLaunchStage).
    """
    title: pulumi.Output[str]
    """
    A human-readable title for the role.
    """
    def __init__(__self__, resource_name, opts=None, description=None, org_id=None, permissions=None, role_id=None, stage=None, title=None, __props__=None, __name__=None, __opts__=None):
        """
        Allows management of a customized Cloud IAM organization role. For more information see
        [the official documentation](https://cloud.google.com/iam/docs/understanding-custom-roles)
        and
        [API](https://cloud.google.com/iam/reference/rest/v1/organizations.roles).
        
        > **Warning:** Note that custom roles in GCP have the concept of a soft-delete. There are two issues that may arise
         from this and how roles are propagated. 1) creating a role may involve undeleting and then updating a role with the
         same name, possibly causing confusing behavior between undelete and update. 2) A deleted role is permanently deleted
         after 7 days, but it can take up to 30 more days (i.e. between 7 and 37 days after deletion) before the role name is
         made available again. This means a deleted role that has been deleted for more than 7 days cannot be changed at all
         by this provider, and new roles cannot share that name.
        
        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[str] description: A human-readable description for the role.
        :param pulumi.Input[str] org_id: The numeric ID of the organization in which you want to create a custom role.
        :param pulumi.Input[list] permissions: The names of the permissions this role grants when bound in an IAM policy. At least one permission must be specified.
        :param pulumi.Input[str] role_id: The role id to use for this role.
        :param pulumi.Input[str] stage: The current launch stage of the role.
               Defaults to `GA`.
               List of possible stages is [here](https://cloud.google.com/iam/reference/rest/v1/organizations.roles#Role.RoleLaunchStage).
        :param pulumi.Input[str] title: A human-readable title for the role.

        > This content is derived from https://github.com/terraform-providers/terraform-provider-google/blob/master/website/docs/r/organization_iam_custom_role.html.markdown.
        """
        if __name__ is not None:
            warnings.warn("explicit use of __name__ is deprecated", DeprecationWarning)
            resource_name = __name__
        if __opts__ is not None:
            warnings.warn("explicit use of __opts__ is deprecated, use 'opts' instead", DeprecationWarning)
            opts = __opts__
        if opts is None:
            opts = pulumi.ResourceOptions()
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.version is None:
            opts.version = utilities.get_version()
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = dict()

            __props__['description'] = description
            if org_id is None:
                raise TypeError("Missing required property 'org_id'")
            __props__['org_id'] = org_id
            if permissions is None:
                raise TypeError("Missing required property 'permissions'")
            __props__['permissions'] = permissions
            if role_id is None:
                raise TypeError("Missing required property 'role_id'")
            __props__['role_id'] = role_id
            __props__['stage'] = stage
            if title is None:
                raise TypeError("Missing required property 'title'")
            __props__['title'] = title
            __props__['deleted'] = None
        super(IAMCustomRole, __self__).__init__(
            'gcp:organizations/iAMCustomRole:IAMCustomRole',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name, id, opts=None, deleted=None, description=None, org_id=None, permissions=None, role_id=None, stage=None, title=None):
        """
        Get an existing IAMCustomRole resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.
        
        :param str resource_name: The unique name of the resulting resource.
        :param str id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[bool] deleted: (Optional) The current deleted state of the role.
        :param pulumi.Input[str] description: A human-readable description for the role.
        :param pulumi.Input[str] org_id: The numeric ID of the organization in which you want to create a custom role.
        :param pulumi.Input[list] permissions: The names of the permissions this role grants when bound in an IAM policy. At least one permission must be specified.
        :param pulumi.Input[str] role_id: The role id to use for this role.
        :param pulumi.Input[str] stage: The current launch stage of the role.
               Defaults to `GA`.
               List of possible stages is [here](https://cloud.google.com/iam/reference/rest/v1/organizations.roles#Role.RoleLaunchStage).
        :param pulumi.Input[str] title: A human-readable title for the role.

        > This content is derived from https://github.com/terraform-providers/terraform-provider-google/blob/master/website/docs/r/organization_iam_custom_role.html.markdown.
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = dict()
        __props__["deleted"] = deleted
        __props__["description"] = description
        __props__["org_id"] = org_id
        __props__["permissions"] = permissions
        __props__["role_id"] = role_id
        __props__["stage"] = stage
        __props__["title"] = title
        return IAMCustomRole(resource_name, opts=opts, __props__=__props__)
    def translate_output_property(self, prop):
        return tables._CAMEL_TO_SNAKE_CASE_TABLE.get(prop) or prop

    def translate_input_property(self, prop):
        return tables._SNAKE_TO_CAMEL_CASE_TABLE.get(prop) or prop




# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import json
import warnings
import pulumi
import pulumi.runtime
from typing import Union
from .. import utilities, tables

class GetInstanceGroupResult:
    """
    A collection of values returned by getInstanceGroup.
    """
    def __init__(__self__, description=None, instances=None, name=None, named_ports=None, network=None, project=None, self_link=None, size=None, zone=None, id=None):
        if description and not isinstance(description, str):
            raise TypeError("Expected argument 'description' to be a str")
        __self__.description = description
        """
        Textual description of the instance group.
        """
        if instances and not isinstance(instances, list):
            raise TypeError("Expected argument 'instances' to be a list")
        __self__.instances = instances
        """
        List of instances in the group.
        """
        if name and not isinstance(name, str):
            raise TypeError("Expected argument 'name' to be a str")
        __self__.name = name
        if named_ports and not isinstance(named_ports, list):
            raise TypeError("Expected argument 'named_ports' to be a list")
        __self__.named_ports = named_ports
        """
        List of named ports in the group.
        """
        if network and not isinstance(network, str):
            raise TypeError("Expected argument 'network' to be a str")
        __self__.network = network
        """
        The URL of the network the instance group is in.
        """
        if project and not isinstance(project, str):
            raise TypeError("Expected argument 'project' to be a str")
        __self__.project = project
        if self_link and not isinstance(self_link, str):
            raise TypeError("Expected argument 'self_link' to be a str")
        __self__.self_link = self_link
        """
        The URI of the resource.
        """
        if size and not isinstance(size, float):
            raise TypeError("Expected argument 'size' to be a float")
        __self__.size = size
        """
        The number of instances in the group.
        """
        if zone and not isinstance(zone, str):
            raise TypeError("Expected argument 'zone' to be a str")
        __self__.zone = zone
        if id and not isinstance(id, str):
            raise TypeError("Expected argument 'id' to be a str")
        __self__.id = id
        """
        id is the provider-assigned unique ID for this managed resource.
        """
class AwaitableGetInstanceGroupResult(GetInstanceGroupResult):
    # pylint: disable=using-constant-test
    def __await__(self):
        if False:
            yield self
        return GetInstanceGroupResult(
            description=self.description,
            instances=self.instances,
            name=self.name,
            named_ports=self.named_ports,
            network=self.network,
            project=self.project,
            self_link=self.self_link,
            size=self.size,
            zone=self.zone,
            id=self.id)

def get_instance_group(name=None,project=None,self_link=None,zone=None,opts=None):
    """
    Get a Compute Instance Group within GCE.
    For more information, see [the official documentation](https://cloud.google.com/compute/docs/instance-groups/#unmanaged_instance_groups)
    and [API](https://cloud.google.com/compute/docs/reference/latest/instanceGroups)
    
    :param str name: The name of the instance group. Either `name` or `self_link` must be provided.
    :param str project: The ID of the project in which the resource belongs. If it
           is not provided, the provider project is used.
    :param str self_link: The self link of the instance group. Either `name` or `self_link` must be provided.
    :param str zone: The zone of the instance group. If referencing the instance group by name
           and `zone` is not provided, the provider zone is used.

    > This content is derived from https://github.com/terraform-providers/terraform-provider-google/blob/master/website/docs/d/compute_instance_group.html.markdown.
    """
    __args__ = dict()

    __args__['name'] = name
    __args__['project'] = project
    __args__['selfLink'] = self_link
    __args__['zone'] = zone
    if opts is None:
        opts = pulumi.InvokeOptions()
    if opts.version is None:
        opts.version = utilities.get_version()
    __ret__ = pulumi.runtime.invoke('gcp:compute/getInstanceGroup:getInstanceGroup', __args__, opts=opts).value

    return AwaitableGetInstanceGroupResult(
        description=__ret__.get('description'),
        instances=__ret__.get('instances'),
        name=__ret__.get('name'),
        named_ports=__ret__.get('namedPorts'),
        network=__ret__.get('network'),
        project=__ret__.get('project'),
        self_link=__ret__.get('selfLink'),
        size=__ret__.get('size'),
        zone=__ret__.get('zone'),
        id=__ret__.get('id'))



# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import json
import warnings
import pulumi
import pulumi.runtime
from typing import Union
from .. import utilities, tables

class Policy(pulumi.CustomResource):
    boolean_policy: pulumi.Output[dict]
    """
    A boolean policy is a constraint that is either enforced or not. Structure is documented below.
    
      * `enforced` (`bool`)
    """
    constraint: pulumi.Output[str]
    """
    The name of the Constraint the Policy is configuring, for example, `serviceuser.services`. Check out the [complete list of available constraints](https://cloud.google.com/resource-manager/docs/organization-policy/understanding-constraints#available_constraints).
    """
    etag: pulumi.Output[str]
    """
    (Computed) The etag of the organization policy. `etag` is used for optimistic concurrency control as a way to help prevent simultaneous updates of a policy from overwriting each other.
    """
    list_policy: pulumi.Output[dict]
    """
    A policy that can define specific values that are allowed or denied for the given constraint. It can also be used to allow or deny all values. Structure is documented below.
    
      * `allow` (`dict`)
    
        * `all` (`bool`)
        * `values` (`list`)
    
      * `deny` (`dict`)
    
        * `all` (`bool`)
        * `values` (`list`)
    
      * `inheritFromParent` (`bool`)
      * `suggestedValue` (`str`)
    """
    org_id: pulumi.Output[str]
    """
    The numeric ID of the organization to set the policy for.
    """
    restore_policy: pulumi.Output[dict]
    """
    A restore policy is a constraint to restore the default policy. Structure is documented below.
    
      * `default` (`bool`)
    """
    update_time: pulumi.Output[str]
    """
    (Computed) The timestamp in RFC3339 UTC "Zulu" format, accurate to nanoseconds, representing when the variable was last updated. Example: "2016-10-09T12:33:37.578138407Z".
    """
    version: pulumi.Output[float]
    """
    Version of the Policy. Default version is 0.
    """
    def __init__(__self__, resource_name, opts=None, boolean_policy=None, constraint=None, list_policy=None, org_id=None, restore_policy=None, version=None, __props__=None, __name__=None, __opts__=None):
        """
        Allows management of Organization policies for a Google Organization. For more information see
        [the official
        documentation](https://cloud.google.com/resource-manager/docs/organization-policy/overview) and
        [API](https://cloud.google.com/resource-manager/reference/rest/v1/organizations/setOrgPolicy).
        
        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[dict] boolean_policy: A boolean policy is a constraint that is either enforced or not. Structure is documented below.
        :param pulumi.Input[str] constraint: The name of the Constraint the Policy is configuring, for example, `serviceuser.services`. Check out the [complete list of available constraints](https://cloud.google.com/resource-manager/docs/organization-policy/understanding-constraints#available_constraints).
        :param pulumi.Input[dict] list_policy: A policy that can define specific values that are allowed or denied for the given constraint. It can also be used to allow or deny all values. Structure is documented below.
        :param pulumi.Input[str] org_id: The numeric ID of the organization to set the policy for.
        :param pulumi.Input[dict] restore_policy: A restore policy is a constraint to restore the default policy. Structure is documented below.
        :param pulumi.Input[float] version: Version of the Policy. Default version is 0.
        
        The **boolean_policy** object supports the following:
        
          * `enforced` (`pulumi.Input[bool]`)
        
        The **list_policy** object supports the following:
        
          * `allow` (`pulumi.Input[dict]`)
        
            * `all` (`pulumi.Input[bool]`)
            * `values` (`pulumi.Input[list]`)
        
          * `deny` (`pulumi.Input[dict]`)
        
            * `all` (`pulumi.Input[bool]`)
            * `values` (`pulumi.Input[list]`)
        
          * `inheritFromParent` (`pulumi.Input[bool]`)
          * `suggestedValue` (`pulumi.Input[str]`)
        
        The **restore_policy** object supports the following:
        
          * `default` (`pulumi.Input[bool]`)

        > This content is derived from https://github.com/terraform-providers/terraform-provider-google/blob/master/website/docs/r/organization_policy.html.markdown.
        """
        if __name__ is not None:
            warnings.warn("explicit use of __name__ is deprecated", DeprecationWarning)
            resource_name = __name__
        if __opts__ is not None:
            warnings.warn("explicit use of __opts__ is deprecated, use 'opts' instead", DeprecationWarning)
            opts = __opts__
        if opts is None:
            opts = pulumi.ResourceOptions()
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.version is None:
            opts.version = utilities.get_version()
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = dict()

            __props__['boolean_policy'] = boolean_policy
            if constraint is None:
                raise TypeError("Missing required property 'constraint'")
            __props__['constraint'] = constraint
            __props__['list_policy'] = list_policy
            if org_id is None:
                raise TypeError("Missing required property 'org_id'")
            __props__['org_id'] = org_id
            __props__['restore_policy'] = restore_policy
            __props__['version'] = version
            __props__['etag'] = None
            __props__['update_time'] = None
        super(Policy, __self__).__init__(
            'gcp:organizations/policy:Policy',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name, id, opts=None, boolean_policy=None, constraint=None, etag=None, list_policy=None, org_id=None, restore_policy=None, update_time=None, version=None):
        """
        Get an existing Policy resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.
        
        :param str resource_name: The unique name of the resulting resource.
        :param str id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[dict] boolean_policy: A boolean policy is a constraint that is either enforced or not. Structure is documented below.
        :param pulumi.Input[str] constraint: The name of the Constraint the Policy is configuring, for example, `serviceuser.services`. Check out the [complete list of available constraints](https://cloud.google.com/resource-manager/docs/organization-policy/understanding-constraints#available_constraints).
        :param pulumi.Input[str] etag: (Computed) The etag of the organization policy. `etag` is used for optimistic concurrency control as a way to help prevent simultaneous updates of a policy from overwriting each other.
        :param pulumi.Input[dict] list_policy: A policy that can define specific values that are allowed or denied for the given constraint. It can also be used to allow or deny all values. Structure is documented below.
        :param pulumi.Input[str] org_id: The numeric ID of the organization to set the policy for.
        :param pulumi.Input[dict] restore_policy: A restore policy is a constraint to restore the default policy. Structure is documented below.
        :param pulumi.Input[str] update_time: (Computed) The timestamp in RFC3339 UTC "Zulu" format, accurate to nanoseconds, representing when the variable was last updated. Example: "2016-10-09T12:33:37.578138407Z".
        :param pulumi.Input[float] version: Version of the Policy. Default version is 0.
        
        The **boolean_policy** object supports the following:
        
          * `enforced` (`pulumi.Input[bool]`)
        
        The **list_policy** object supports the following:
        
          * `allow` (`pulumi.Input[dict]`)
        
            * `all` (`pulumi.Input[bool]`)
            * `values` (`pulumi.Input[list]`)
        
          * `deny` (`pulumi.Input[dict]`)
        
            * `all` (`pulumi.Input[bool]`)
            * `values` (`pulumi.Input[list]`)
        
          * `inheritFromParent` (`pulumi.Input[bool]`)
          * `suggestedValue` (`pulumi.Input[str]`)
        
        The **restore_policy** object supports the following:
        
          * `default` (`pulumi.Input[bool]`)

        > This content is derived from https://github.com/terraform-providers/terraform-provider-google/blob/master/website/docs/r/organization_policy.html.markdown.
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = dict()
        __props__["boolean_policy"] = boolean_policy
        __props__["constraint"] = constraint
        __props__["etag"] = etag
        __props__["list_policy"] = list_policy
        __props__["org_id"] = org_id
        __props__["restore_policy"] = restore_policy
        __props__["update_time"] = update_time
        __props__["version"] = version
        return Policy(resource_name, opts=opts, __props__=__props__)
    def translate_output_property(self, prop):
        return tables._CAMEL_TO_SNAKE_CASE_TABLE.get(prop) or prop

    def translate_input_property(self, prop):
        return tables._SNAKE_TO_CAMEL_CASE_TABLE.get(prop) or prop

